from networkx.utils.backends import _dispatchable as _dispatchable
from networkx.utils.configs import *
from networkx.utils.decorators import *
from networkx.utils.heaps import *

# should be import * but pytype doesn't understand that _clear_cache is part of __all__
from networkx.utils.misc import (
    PythonRandomInterface as PythonRandomInterface,
    PythonRandomViaNumpyBits as PythonRandomViaNumpyBits,
    _clear_cache as _clear_cache,
    arbitrary_element as arbitrary_element,
    create_py_random_state as create_py_random_state,
    create_random_state as create_random_state,
    dict_to_numpy_array as dict_to_numpy_array,
    edges_equal as edges_equal,
    flatten as flatten,
    graphs_equal as graphs_equal,
    groups as groups,
    make_list_of_ints as make_list_of_ints,
    nodes_equal as nodes_equal,
    pairwise as pairwise,
)
from networkx.utils.random_sequence import *
from networkx.utils.rcm import *
from networkx.utils.union_find import *



from collections.abc import Callable
from typing import Any, Generic, Protocol, TypeVar
from typing_extensions import Self

class _HasId(Protocol):
    @property
    def id(self) -> str | None: ...

_R = TypeVar("_R", default=Any)
_T = TypeVar("_T", bound=_HasId)

class _Page(Generic[_T]):
    has_next: bool
    values: list[_T]
    next_after: str | None

    def __init__(self, values: list[_T], has_next: bool, next_after: str | None) -> None: ...
    @staticmethod
    def empty() -> _Page[_T]: ...
    @staticmethod
    def initial(after: str | None) -> _Page[_T]: ...

class _PageIterator(Generic[_T]):
    page: _Page[_T]
    get_next_page: Callable[[_Page[_T]], _Page[_T]]

    def __init__(self, page: _Page[_T], get_next_page: Callable[[_Page[_T]], _Page[_T]]) -> None: ...
    def __iter__(self) -> Self: ...
    def __next__(self) -> _T: ...

class _Paginated(Generic[_T, _R]):
    paginated_getter: Callable[..., _R]  # Gets passed additional kwargs to find_iter().
    pluck_page_resources_from_response: Callable[[_R], list[_T]]
    def __init__(
        self, paginated_getter: Callable[..., _R], pluck_page_resources_from_response: Callable[[_R], list[_T]]
    ) -> None: ...
    def find_iter(self, *, after: str | None = None, **kwargs: Any) -> _PageIterator[_T]: ...



from _typeshed import Incomplete

from networkx.utils.backends import _dispatchable

@_dispatchable
def maximal_independent_set(G, nodes: Incomplete | None = None, seed: Incomplete | None = None): ...



from _typeshed import Incomplete
from collections.abc import Generator

from corus.record import Record

class SimlexRecord(Record):
    __attributes__: Incomplete
    word1: Incomplete
    word2: Incomplete
    score: Incomplete
    def __init__(self, word1, word2, score) -> None: ...

def parse_simlex(lines) -> Generator[Incomplete]: ...
def load_simlex(path): ...



from _typeshed import Incomplete

def prepare_grant_uri(
    uri,
    client_id,
    response_type,
    redirect_uri: Incomplete | None = None,
    scope: Incomplete | None = None,
    state: Incomplete | None = None,
    **kwargs,
): ...
def prepare_token_request(grant_type, body: str = "", redirect_uri: Incomplete | None = None, **kwargs): ...
def parse_authorization_code_response(uri, state: Incomplete | None = None): ...
def parse_implicit_response(uri, state: Incomplete | None = None): ...



from _typeshed import Incomplete

__all__ = ["load_taiga_nplus1_metas", "load_taiga_nplus1"]

def load_taiga_nplus1_metas(path, offset: int = 0, count: int = 1): ...
def load_taiga_nplus1(path, metas: Incomplete | None = None, offset: int = 1919488, count: int = 7696): ...



from _typeshed import Incomplete

ASSERTION_TYPE: str

class JWTBearerClientAssertion:
    CLIENT_ASSERTION_TYPE = ASSERTION_TYPE
    CLIENT_AUTH_METHOD: str
    token_url: Incomplete
    def __init__(self, token_url, validate_jti: bool = True) -> None: ...
    def __call__(self, query_client, request): ...
    def create_claims_options(self): ...
    def process_assertion_claims(self, assertion, resolve_key): ...
    def authenticate_client(self, client): ...
    def create_resolve_key_func(self, query_client, request): ...
    def validate_jti(self, claims, jti) -> None: ...
    def resolve_client_public_key(self, client, headers) -> None: ...



from _typeshed import Incomplete
from collections.abc import Generator

from corus.record import Record

class OmniaDoc(Record):
    __attributes__: Incomplete
    id: Incomplete
    attrs: Incomplete
    pars: Incomplete
    def __init__(self, id, attrs, pars) -> None: ...

class OmniaPar(Record):
    __attributes__: Incomplete
    sents: Incomplete
    def __init__(self, sents) -> None: ...

class OmniaSent(Record):
    __attributes__: Incomplete
    tokens: Incomplete
    def __init__(self, tokens) -> None: ...

class OmniaToken(Record):
    __attributes__: Incomplete
    text: Incomplete
    lemma: Incomplete
    atag: Incomplete
    tag: Incomplete
    ztag: Incomplete
    g: Incomplete
    def __init__(self, text, lemma, atag, tag, ztag, g) -> None: ...

DID: str
G_TAG: str
S_END: str
P_END: str
DOC_END: str

def take_until(stream, value) -> Generator[Incomplete]: ...
def group_bounds(stream, end) -> Generator[Incomplete]: ...
def group_doc_bounds(stream) -> Generator[Incomplete]: ...
def group_pairs(stream) -> Generator[Incomplete]: ...
def parse_tokens(lines) -> Generator[Incomplete]: ...
def parse_sents(lines) -> Generator[Incomplete]: ...
def parse_pars(lines) -> Generator[Incomplete]: ...
def parse_tag_attrs(tag) -> Generator[Incomplete]: ...
def parse_doc_header(header): ...
def parse_docs(lines) -> Generator[Incomplete]: ...
def load_omnia(path) -> Generator[Incomplete, Incomplete, None]: ...



from _typeshed import Incomplete
from collections.abc import Generator

def parse_metas(items) -> Generator[Incomplete]: ...
def load_taiga_subtitles_metas(path, offset: int = 0, count: int = 1): ...
def load_taiga_subtitles(path, metas: Incomplete | None = None, offset: int = 2113024, count: int = 19011): ...



from _typeshed import Incomplete
from collections.abc import Generator

from corus.record import Record

TEXT: str
ANNO: str

class PersonsSpan(Record):
    __attributes__: Incomplete
    id: Incomplete
    start: Incomplete
    stop: Incomplete
    value: Incomplete
    def __init__(self, id, start, stop, value) -> None: ...

class PersonsMarkup(Record):
    __attributes__: Incomplete
    text: Incomplete
    spans: Incomplete
    def __init__(self, text, spans) -> None: ...

def list_ids(path) -> Generator[Incomplete]: ...
def part_names(ids, part) -> Generator[Incomplete]: ...
def parse_anno(text) -> Generator[Incomplete]: ...
def load_ids(ids, path) -> Generator[Incomplete]: ...
def load_persons(path): ...



import datetime
from collections.abc import Callable
from typing import Final

__all__ = ["main"]

def check(dt: datetime.datetime, tz: datetime.tzinfo) -> tuple[datetime.datetime, datetime.timedelta]: ...
def checks(tz: datetime.tzinfo) -> list[tuple[datetime.datetime, datetime.timedelta]]: ...

START: Final[datetime.datetime]
END: Final[datetime.datetime]

DTS: Final[list[datetime.datetime]]

def main(create_timezones: list[Callable[[str], datetime.tzinfo]], name: str, pool_size: int = ...) -> None: ...



from _typeshed import Incomplete

class JsonWebToken:
    SENSITIVE_NAMES: Incomplete
    SENSITIVE_VALUES: Incomplete
    def __init__(self, algorithms, private_headers: Incomplete | None = None) -> None: ...
    def check_sensitive_data(self, payload) -> None: ...
    def encode(self, header, payload, key, check: bool = True): ...
    def decode(
        self,
        s,
        key,
        claims_cls: Incomplete | None = None,
        claims_options: Incomplete | None = None,
        claims_params: Incomplete | None = None,
    ): ...

def decode_payload(bytes_payload): ...
def prepare_raw_key(raw): ...
def find_encode_key(key, header): ...
def create_load_key(key): ...



from _typeshed import Incomplete

from braintree.graphql.inputs.customer_session_input import CustomerSessionInput

class CreateCustomerSessionInput:
    def __init__(
        self,
        merchant_account_id: str | None = None,
        session_id: str | None = None,
        customer: CustomerSessionInput | None = None,
        domain: str | None = None,
    ) -> None: ...
    def to_graphql_variables(self) -> dict[Incomplete, Incomplete]: ...
    @staticmethod
    def builder(): ...

    class Builder:
        def __init__(self) -> None: ...
        def merchant_account_id(self, merchant_account_id: str): ...
        def session_id(self, session_id: str): ...
        def customer(self, customer: str): ...
        def domain(self, domain: str): ...
        def build(self): ...



from .arzamas import *
from .fontanka import *
from .interfax import *
from .kp import *
from .lenta import *
from .magazines import *
from .nplus1 import *
from .proza import *
from .social import *
from .subtitles import *



from networkx.utils.backends import _dispatchable

@_dispatchable
def tensor_product(G, H): ...
@_dispatchable
def cartesian_product(G, H): ...
@_dispatchable
def lexicographic_product(G, H): ...
@_dispatchable
def strong_product(G, H): ...
@_dispatchable
def power(G, k): ...
@_dispatchable
def rooted_product(G, H, root): ...
@_dispatchable
def corona_product(G, H): ...



from networkx.utils.backends import _dispatchable

@_dispatchable
def d_separated(G, x, y, z): ...
@_dispatchable
def minimal_d_separator(G, u, v): ...
@_dispatchable
def is_minimal_d_separator(G, u, v, z): ...



from _typeshed import Incomplete
from collections.abc import Generator

from corus.record import Record

class Ne5Span(Record):
    __attributes__: Incomplete
    index: Incomplete
    type: Incomplete
    start: Incomplete
    stop: Incomplete
    text: Incomplete
    def __init__(self, index, type, start, stop, text) -> None: ...

class Ne5Markup(Record):
    __attributes__: Incomplete
    id: Incomplete
    text: Incomplete
    spans: Incomplete
    def __init__(self, id, text, spans) -> None: ...

def list_ids(dir) -> Generator[Incomplete]: ...
def txt_path(id, dir): ...
def ann_path(id, dir): ...
def parse_spans(lines) -> Generator[Incomplete]: ...
def load_text(path): ...
def load_id(id, dir): ...
def load_ne5(dir) -> Generator[Incomplete]: ...



from _typeshed import Incomplete

__all__ = ["load_taiga_proza_metas", "load_taiga_proza", "load_taiga_stihi_metas", "load_taiga_stihi"]

def load_taiga_proza_metas(path, offset: int = 0, count=13): ...
def load_taiga_stihi_metas(path, offset: int = 0, count=3): ...
def load_taiga_proza(path, metas: Incomplete | None = None, offset: int = ..., count: int = ...): ...
def load_taiga_stihi(path, metas: Incomplete | None = None, offset: int = ..., count: int = ...): ...



from _typeshed import Incomplete

from networkx.utils.backends import _dispatchable

@_dispatchable
def min_edge_cover(G, matching_algorithm: Incomplete | None = None): ...
@_dispatchable
def is_edge_cover(G, cover): ...



import typing
from _typeshed import Incomplete
from collections.abc import Generator
from math import (
    acos as acos,
    asin as asin,
    atan as atan,
    ceil as ceil,
    cos as cos,
    exp as exp,
    floor as floor,
    pi as pi,
    sin as sin,
    tan as tan,
    trunc as trunc,
)

PY2: Incomplete
text_type = str
version: str
options: Incomplete
templateKeys: Incomplete
filter_disambig_page_pattern: Incomplete
g_page_total: int
g_page_articl_total: int
g_page_articl_used_total: int

def keepPage(ns, catSet, page): ...
def get_url(uid): ...

selfClosingTags: Incomplete
placeholder_tags: Incomplete

def normalizeTitle(title): ...
def unescape(text): ...

comment: Incomplete
nowiki: Incomplete

def ignoreTag(tag) -> None: ...

selfClosing_tag_patterns: Incomplete
placeholder_tag_patterns: Incomplete
preformatted: Incomplete
externalLink: Incomplete
externalLinkNoAnchor: Incomplete
bold_italic: Incomplete
bold: Incomplete
italic_quote: Incomplete
italic: Incomplete
quote_quote: Incomplete
spaces: Incomplete
dots: Incomplete

_T = typing.TypeVar("_T")

class Template(list[_T]):
    @classmethod
    def parse(cls, body): ...
    def subst(self, params, extractor, depth: int = 0): ...

class TemplateText(text_type):
    def subst(self, params, extractor, depth): ...

class TemplateArg:
    name: Incomplete
    default: Incomplete
    def __init__(self, parameter) -> None: ...
    def subst(self, params, extractor, depth): ...

class Frame:
    title: Incomplete
    args: Incomplete
    prev: Incomplete
    depth: Incomplete
    def __init__(self, title: str = "", args=[], prev: Incomplete | None = None) -> None: ...
    def push(self, title, args): ...
    def pop(self): ...

substWords: str

class Extractor:
    id: Incomplete
    revid: Incomplete
    title: Incomplete
    text: Incomplete
    magicWords: Incomplete
    frame: Incomplete
    recursion_exceeded_1_errs: int
    recursion_exceeded_2_errs: int
    recursion_exceeded_3_errs: int
    template_title_errs: int
    def __init__(self, id, revid, title, lines) -> None: ...
    def write_output(self, out, text) -> None: ...
    def extract(self, out) -> None: ...
    def transform(self, wikitext): ...
    def transform1(self, text): ...
    def wiki2text(self, text): ...
    def clean(self, text): ...
    maxTemplateRecursionLevels: int
    maxParameterRecursionLevels: int
    reOpen: Incomplete
    def expand(self, wikitext): ...
    def templateParams(self, parameters): ...
    def expandTemplate(self, body): ...

def splitParts(paramsList): ...
def findMatchingBraces(text, ldelim: int = 0) -> Generator[Incomplete]: ...
def findBalanced(text, openDelim=["[["], closeDelim=["]]"]) -> Generator[Incomplete]: ...
def if_empty(*rest): ...
def functionParams(args, vars): ...
def string_sub(args): ...
def string_sublength(args): ...
def string_len(args): ...
def string_find(args): ...
def string_pos(args): ...
def string_replace(args): ...
def string_rep(args): ...
def roman_main(args): ...

modules: Incomplete

class MagicWords:
    names: Incomplete
    values: Incomplete
    def __init__(self) -> None: ...
    def __getitem__(self, name): ...
    def __setitem__(self, name, value) -> None: ...
    switches: Incomplete

magicWordsRE: Incomplete

def ucfirst(string): ...
def lcfirst(string): ...
def fullyQualifiedTemplateTitle(templateTitle): ...
def normalizeNamespace(ns): ...

class Infix:
    function: Incomplete
    def __init__(self, function) -> None: ...
    def __ror__(self, other): ...
    def __or__(self, other): ...
    def __rlshift__(self, other): ...
    def __rshift__(self, other): ...
    def __call__(self, value1, value2): ...

ROUND: Incomplete

def sharp_expr(extr, expr): ...
def sharp_if(extr, testValue, valueIfTrue, valueIfFalse: Incomplete | None = None, *args): ...
def sharp_ifeq(extr, lvalue, rvalue, valueIfTrue, valueIfFalse: Incomplete | None = None, *args): ...
def sharp_iferror(extr, test, then: str = "", Else: Incomplete | None = None, *args): ...
def sharp_switch(extr, primary, *params): ...
def sharp_invoke(module, function, args): ...

parserFunctions: Incomplete

def callParserFunction(functionName, args, extractor): ...

reNoinclude: Incomplete
reIncludeonly: Incomplete

def define_template(title, page) -> None: ...
def dropNested(text, openDelim, closeDelim): ...
def dropSpans(spans, text): ...
def replaceInternalLinks(text): ...
def makeInternalLink(title, label): ...

wgUrlProtocols: Incomplete
EXT_LINK_URL_CLASS: str
ANCHOR_CLASS: str
ExtLinkBracketedRegex: Incomplete
EXT_IMAGE_REGEX: Incomplete

def replaceExternalLinks(text): ...
def makeExternalLink(url, anchor): ...
def makeExternalImage(url, alt: str = ""): ...

tailRE: Incomplete
syntaxhighlight: Incomplete
section: Incomplete
listOpen: Incomplete
listClose: Incomplete
listItem: Incomplete

def compact(text): ...
def handle_unicode(entity): ...

class NextFile:
    filesPerDir: int
    path_name: Incomplete
    dir_index: int
    file_index: int
    def __init__(self, path_name) -> None: ...
    def __next__(self): ...
    next = __next__

class OutputSplitter:
    nextFile: Incomplete
    compress: Incomplete
    max_file_size: Incomplete
    file: Incomplete
    def __init__(self, nextFile, max_file_size: int = 0, compress: bool = True) -> None: ...
    def reserve(self, size) -> None: ...
    def write(self, data) -> None: ...
    def close(self) -> None: ...
    def open(self, filename): ...

tagRE: Incomplete
keyRE: Incomplete
catRE: Incomplete

def load_templates(file, output_file: Incomplete | None = None) -> None: ...
def pages_from(input) -> Generator[Incomplete]: ...
def process_dump(input_file, template_file, out_file, file_size, file_compress, process_count) -> None: ...
def extract_process(opts, i, jobs_queue, output_queue) -> None: ...

report_period: int

def reduce_process(
    opts, output_queue, spool_length, out_file: Incomplete | None = None, file_size: int = 0, file_compress: bool = True
) -> None: ...

minFileSize: Incomplete

def main() -> None: ...
def createLogger(quiet, debug, log_file) -> None: ...



from _typeshed import Incomplete
from typing import NamedTuple

def open_zip(path): ...

HEADER_FORMAT: str
HEADER_SIGNATURE: bytes
NO_COMPRESSION: int
DEFLATED: int

class ZipHeader(NamedTuple):
    signature: Incomplete
    extract_by: Incomplete
    flags: Incomplete
    compression: Incomplete
    time: Incomplete
    date: Incomplete
    crc: Incomplete
    compressed: Incomplete
    uncompressed: Incomplete
    name: Incomplete
    extra: Incomplete

def decode_name(name): ...
def read_zip_header(file): ...
def is_zip_header(record): ...
def assert_zip_header(record) -> None: ...
def read_zip_data(file, header): ...



from _typeshed import Incomplete

from authlib.oauth2 import OAuth2Error

__all__ = ["InvalidTokenError", "InsufficientScopeError"]

class InvalidTokenError(OAuth2Error):
    error: str
    description: str
    status_code: int
    realm: Incomplete
    extra_attributes: Incomplete
    def __init__(
        self,
        description: Incomplete | None = None,
        uri: Incomplete | None = None,
        status_code: Incomplete | None = None,
        state: Incomplete | None = None,
        realm: Incomplete | None = None,
        **extra_attributes,
    ) -> None: ...
    def get_headers(self): ...

class InsufficientScopeError(OAuth2Error):
    error: str
    description: str
    status_code: int



import re

class RomanError(Exception): ...
class OutOfRangeError(RomanError): ...
class NotIntegerError(RomanError): ...
class InvalidRomanNumeralError(RomanError): ...

romanNumeralMap: tuple[tuple[str, int], ...]

def toRoman(n: int) -> str: ...

romanNumeralPattern: re.Pattern[str]

def fromRoman(s: str) -> int: ...



from _typeshed import Incomplete
from typing import Literal
from typing_extensions import TypeAlias

import numpy as np
from numpy.typing import NDArray

from ..array import GeometryArray
from ..geodataframe import GeoDataFrame

_PATable: TypeAlias = Incomplete
_PAField: TypeAlias = Incomplete
_PAArray: TypeAlias = Incomplete

# Literal for language server completions and str because runtime normalizes to lowercase
_GeomEncoding: TypeAlias = Literal["WKB", "geoarrow"] | str  # noqa: Y051

GEOARROW_ENCODINGS: list[str]

class ArrowTable:
    def __init__(self, pa_table: _PATable) -> None: ...
    def __arrow_c_stream__(self, requested_schema=None): ...

class GeoArrowArray:
    def __init__(self, pa_field: _PAField, pa_array: _PAArray) -> None: ...
    def __arrow_c_array__(self, requested_schema=None) -> tuple[Incomplete, Incomplete]: ...

def geopandas_to_arrow(
    df: GeoDataFrame,
    index: bool | None = None,
    geometry_encoding: _GeomEncoding = "WKB",
    interleaved: bool = True,
    include_z: bool | None = None,
) -> tuple[_PATable, dict[str, str]]: ...
def construct_wkb_array(
    shapely_arr: NDArray[np.object_], *, field_name: str = "geometry", crs: str | None = None
) -> tuple[_PAField, _PAArray]: ...
def construct_geometry_array(
    shapely_arr: NDArray[np.object_],
    include_z: bool | None = None,
    *,
    field_name: str = "geometry",
    crs: str | None = None,
    interleaved: bool = True,
) -> tuple[_PAField, _PAArray]: ...
def arrow_to_geopandas(table, geometry: str | None = None) -> GeoDataFrame: ...
def arrow_to_geometry_array(arr) -> GeometryArray: ...
def construct_shapely_array(arr: _PAArray, extension_name: str) -> NDArray[np.object_]: ...



from _typeshed import Incomplete
from collections.abc import Generator

from corus.record import Record

class CorporaText(Record):
    __attributes__: Incomplete
    id: Incomplete
    parent_id: Incomplete
    name: Incomplete
    tags: Incomplete
    pars: Incomplete
    def __init__(self, id, parent_id, name, tags, pars) -> None: ...

class CorporaPar(Record):
    __attributes__: Incomplete
    id: Incomplete
    sents: Incomplete
    def __init__(self, id, sents) -> None: ...

class CorporaSent(Record):
    __attributes__: Incomplete
    id: Incomplete
    text: Incomplete
    tokens: Incomplete
    def __init__(self, id, text, tokens) -> None: ...

class CorporaToken(Record):
    __attributes__: Incomplete
    id: Incomplete
    rev_id: Incomplete
    text: Incomplete
    forms: Incomplete
    def __init__(self, id, rev_id, text, forms) -> None: ...

class CorporaForm(Record):
    __attributes__: Incomplete
    id: Incomplete
    text: Incomplete
    grams: Incomplete
    def __init__(self, id, text, grams) -> None: ...

def parse_grams(xml) -> Generator[Incomplete]: ...
def parse_forms(xml) -> Generator[Incomplete]: ...
def parse_tokens(xml) -> Generator[Incomplete]: ...
def parse_sents(xml) -> Generator[Incomplete]: ...
def parse_pars(xml) -> Generator[Incomplete]: ...
def parse_tags(xml) -> Generator[Incomplete]: ...
def parse_text(xml): ...
def load_corpora(path) -> Generator[Incomplete]: ...



from networkx.utils.backends import _dispatchable

@_dispatchable
def maximum_independent_set(G): ...
@_dispatchable
def max_clique(G): ...
@_dispatchable
def clique_removal(G): ...
@_dispatchable
def large_clique_size(G): ...



from _typeshed import Incomplete

from braintree.graphql.enums import RecommendedPaymentOption

class PaymentOptions:
    payment_option: Incomplete
    recommended_priority: Incomplete
    def __init__(self, payment_option: RecommendedPaymentOption, recommended_priority: int) -> None: ...



from collections.abc import Sequence

def change_tz(cal, new_timezone, default, utc_only: bool = False, utc_tz=...) -> None: ...
def show_timezones() -> None: ...
def convert_events(utc_only: bool, args: Sequence[str]) -> None: ...
def main() -> None: ...

version: str

def get_options(): ...



import re
import typing as t

import click

class EmailParamType(click.ParamType):
    EMAIL_REGEX: re.Pattern[str]
    def convert(self, value: t.Any, param: click.Parameter | None, ctx: click.Context | None) -> t.Any: ...

class PasswordParamType(click.ParamType):
    def convert(self, value: t.Any, param: click.Parameter | None, ctx: click.Context | None) -> t.Any: ...

class TextAreaParamType(click.ParamType):
    def convert(self, value: t.Any, param: click.Parameter | None, ctx: click.Context | None) -> t.Any: ...

EMAIL_TYPE: EmailParamType
PASSWORD_TYPE: PasswordParamType
TEXTAREA_TYPE: TextAreaParamType



from _typeshed import Incomplete
from collections.abc import Generator

from networkx.utils.backends import _dispatchable

@_dispatchable
def attracting_components(G) -> Generator[Incomplete, None, None]: ...
@_dispatchable
def number_attracting_components(G): ...
@_dispatchable
def is_attracting_component(G): ...



from _typeshed import Incomplete

import networkx as nx

__all__ = ["edge_betweenness_partition", "edge_current_flow_betweenness_partition"]

@nx._dispatchable
def edge_betweenness_partition(G, number_of_sets: int, *, weight: Incomplete | None = None) -> list[Incomplete]: ...
@nx._dispatchable
def edge_current_flow_betweenness_partition(G, number_of_sets: int, *, weight: Incomplete | None = None) -> list[Incomplete]: ...



from _typeshed import Incomplete

__all__ = ["load_taiga_interfax_metas", "load_taiga_interfax"]

def load_taiga_interfax_metas(path, offset: int = 0, count: int = 1): ...
def load_taiga_interfax(path, metas: Incomplete | None = None, offset: int = 11447296, count: int = 46429): ...



from _typeshed import Incomplete

class AuthlibDeprecationWarning(DeprecationWarning): ...

def deprecate(
    message, version: Incomplete | None = None, link_uid: Incomplete | None = None, link_file: Incomplete | None = None
) -> None: ...



from networkx.utils.backends import _dispatchable

@_dispatchable
def is_regular(G): ...
@_dispatchable
def is_k_regular(G, k): ...
@_dispatchable
def k_factor(G, k, matching_weight: str = "weight"): ...



from _typeshed import Incomplete

DOCKER_CONFIG_FILENAME: Incomplete
LEGACY_DOCKER_CONFIG_FILENAME: str
log: Incomplete

def find_config_file(config_path: Incomplete | None = None): ...
def config_path_from_environment(): ...
def home_dir(): ...
def load_general_config(config_path: Incomplete | None = None): ...



from _typeshed import Incomplete

from networkx.utils.backends import _dispatchable

@_dispatchable
def margulis_gabber_galil_graph(n, create_using: Incomplete | None = None): ...
@_dispatchable
def chordal_cycle_graph(p, create_using: Incomplete | None = None): ...
@_dispatchable
def paley_graph(p, create_using: Incomplete | None = None): ...



from _typeshed import Incomplete

from networkx.utils.backends import _dispatchable

@_dispatchable
def modularity_matrix(G, nodelist: Incomplete | None = None, weight: Incomplete | None = None): ...
@_dispatchable
def directed_modularity_matrix(G, nodelist: Incomplete | None = None, weight: Incomplete | None = None): ...



from _typeshed import Incomplete
from collections.abc import Generator

from corus.record import Record

class WikinerToken(Record):
    __attributes__: Incomplete
    text: Incomplete
    pos: Incomplete
    tag: Incomplete
    def __init__(self, text, pos, tag) -> None: ...

class WikinerMarkup(Record):
    __attributes__: Incomplete
    tokens: Incomplete
    def __init__(self, tokens) -> None: ...

def parse_wikiner(line): ...
def load_wikiner(path) -> Generator[Incomplete]: ...



from _typeshed import Incomplete

from corus.record import Record

__all__ = ["load_ria_raw", "load_ria"]

class RiaRawRecord(Record):
    __attributes__: Incomplete
    title: Incomplete
    text: Incomplete
    def __init__(self, title, text) -> None: ...

class RiaRecord(Record):
    __attributes__: Incomplete
    title: Incomplete
    prefix: Incomplete
    text: Incomplete
    def __init__(self, title, prefix, text) -> None: ...

def load_ria_raw(path): ...
def load_ria(path): ...



from _typeshed import Incomplete

__all__ = ["load_taiga_magazines_metas", "load_taiga_magazines"]

def load_taiga_magazines_metas(path, offset: int = 0, count: int = 36): ...
def load_taiga_magazines(path, metas: Incomplete | None = None, offset: int = 7292416, count: int = 39890): ...



from _typeshed import Incomplete

from braintree.graphql.unions.customer_recommendations import CustomerRecommendations

class CustomerRecommendationsPayload:
    is_in_paypal_network: Incomplete
    recommendations: Incomplete
    def __init__(self, is_in_paypal_network: bool, recommendations: CustomerRecommendations) -> None: ...



import configparser
import urllib.request
from _typeshed import Incomplete
from collections.abc import Generator
from hashlib import _Hash
from re import Pattern
from typing import ClassVar
from typing_extensions import NamedTuple

from pkg_resources import Distribution, Environment

__all__ = ["PackageIndex", "distros_for_url", "parse_bdist_wininst", "interpret_distro_name"]

def parse_bdist_wininst(name): ...
def distros_for_url(url, metadata: Incomplete | None = None) -> Generator[Distribution]: ...
def distros_for_location(
    location, basename, metadata: Incomplete | None = None
) -> list[Distribution] | Generator[Distribution]: ...
def interpret_distro_name(
    location, basename, metadata, py_version: Incomplete | None = None, precedence=1, platform: Incomplete | None = None
) -> Generator[Distribution]: ...

class ContentChecker:
    def feed(self, block) -> None: ...
    def is_valid(self): ...
    def report(self, reporter, template) -> None: ...

class HashChecker(ContentChecker):
    pattern: ClassVar[Pattern[str]]
    hash_name: Incomplete
    hash: _Hash
    expected: Incomplete
    def __init__(self, hash_name, expected) -> None: ...
    @classmethod
    def from_url(cls, url): ...
    def feed(self, block) -> None: ...
    def is_valid(self): ...
    def report(self, reporter, template): ...

class PackageIndex(Environment):
    index_url: str
    scanned_urls: dict[Incomplete, Incomplete]
    fetched_urls: dict[Incomplete, Incomplete]
    package_pages: dict[Incomplete, Incomplete]
    allows: Incomplete
    to_scan: list[Incomplete]
    opener = urllib.request.urlopen
    def __init__(
        self,
        index_url: str = "https://pypi.org/simple/",
        hosts=("*",),
        ca_bundle: Incomplete | None = None,
        verify_ssl: bool = True,
        *args,
        **kw,
    ) -> None: ...
    def process_url(self, url, retrieve: bool = False) -> None: ...
    def process_filename(self, fn, nested: bool = False) -> None: ...
    def url_ok(self, url, fatal: bool = False): ...
    def scan_egg_links(self, search_path) -> None: ...
    def scan_egg_link(self, path, entry) -> None: ...
    def process_index(self, url, page): ...
    def need_version_info(self, url) -> None: ...
    def scan_all(self, msg: Incomplete | None = None, *args) -> None: ...
    def find_packages(self, requirement) -> None: ...
    def obtain(self, requirement, installer: Incomplete | None = None): ...
    def check_hash(self, checker, filename, tfp) -> None: ...
    def add_find_links(self, urls) -> None: ...
    def prescan(self) -> None: ...
    def not_found_in_index(self, requirement) -> None: ...
    def download(self, spec, tmpdir): ...
    def fetch_distribution(
        self,
        requirement,
        tmpdir,
        force_scan: bool = False,
        source: bool = False,
        develop_ok: bool = False,
        local_index: Incomplete | None = None,
    ): ...
    def fetch(self, requirement, tmpdir, force_scan: bool = False, source: bool = False): ...
    def gen_setup(self, filename, fragment, tmpdir): ...
    dl_blocksize: int
    def reporthook(self, url, filename, blocknum, blksize, size) -> None: ...
    def open_url(self, url, warning: Incomplete | None = None): ...
    def scan_url(self, url) -> None: ...
    def debug(self, msg, *args) -> None: ...
    def info(self, msg, *args) -> None: ...
    def warn(self, msg, *args) -> None: ...

class Credential(NamedTuple):
    username: str
    password: str

class PyPIConfig(configparser.RawConfigParser):
    def __init__(self) -> None: ...
    @property
    def creds_by_repository(self): ...
    def find_credential(self, url): ...



from _typeshed import Incomplete

from corus.record import Record

class Meta(Record):
    __attributes__: Incomplete
    title: Incomplete
    url: Incomplete
    description: Incomplete
    stats: Incomplete
    instruction: Incomplete
    tags: Incomplete
    functions: Incomplete
    def __init__(
        self,
        title,
        url: Incomplete | None = None,
        description: Incomplete | None = None,
        stats: Incomplete | None = None,
        instruction=(),
        tags=(),
        functions=(),
    ) -> None: ...

class Group(Record):
    __attributes__: Incomplete
    title: Incomplete
    url: Incomplete
    description: Incomplete
    instruction: Incomplete
    metas: Incomplete
    def __init__(
        self, title, url: Incomplete | None = None, description: Incomplete | None = None, instruction=(), metas=()
    ) -> None: ...

def is_group(item): ...

class Stats(Record):
    __attributes__: Incomplete
    bytes: Incomplete
    count: Incomplete
    def __init__(self, bytes: Incomplete | None = None, count: Incomplete | None = None) -> None: ...

NER: str
NEWS: str
FICTION: str
SOCIAL: str
MORPH: str
SYNTAX: str
EMB: str
SIM: str
SENTIMENT: str
WEB: str
METAS: Incomplete



from enum import IntEnum, IntFlag

class ApplyLocation(IntEnum):
    WORKDIR = 0
    INDEX = 1
    BOTH = 2

class AttrCheck(IntFlag):
    FILE_THEN_INDEX = 0x0
    INDEX_THEN_FILE = 0x1
    INDEX_ONLY = 0x2
    NO_SYSTEM = 0x4
    INCLUDE_HEAD = 0x8
    INCLUDE_COMMIT = 0x10

class BlameFlag(IntFlag):
    NORMAL = 0x0
    TRACK_COPIES_SAME_FILE = 0x1
    TRACK_COPIES_SAME_COMMIT_MOVES = 0x2
    TRACK_COPIES_SAME_COMMIT_COPIES = 0x4
    TRACK_COPIES_ANY_COMMIT_COPIES = 0x8
    FIRST_PARENT = 0x10
    USE_MAILMAP = 0x20
    IGNORE_WHITESPACE = 0x40

class BlobFilter(IntFlag):
    CHECK_FOR_BINARY = 0x1
    NO_SYSTEM_ATTRIBUTES = 0x2
    ATTRIBUTES_FROM_HEAD = 0x4
    ATTRIBUTES_FROM_COMMIT = 0x8

class BranchType(IntFlag):
    LOCAL = 0x1
    REMOTE = 0x2
    ALL = 0x3

class CheckoutNotify(IntFlag):
    NONE = 0x0
    CONFLICT = 0x1
    DIRTY = 0x2
    UPDATED = 0x4
    UNTRACKED = 0x8
    IGNORED = 0x10
    ALL = 0xFFFF

class CheckoutStrategy(IntFlag):
    NONE = 0x0
    SAFE = 0x1
    FORCE = 0x2
    RECREATE_MISSING = 0x4
    ALLOW_CONFLICTS = 0x10
    REMOVE_UNTRACKED = 0x20
    REMOVE_IGNORED = 0x40
    UPDATE_ONLY = 0x80
    DONT_UPDATE_INDEX = 0x100
    NO_REFRESH = 0x200
    SKIP_UNMERGED = 0x400
    USE_OURS = 0x800
    USE_THEIRS = 0x1000
    DISABLE_PATHSPEC_MATCH = 0x2000
    SKIP_LOCKED_DIRECTORIES = 0x40000
    DONT_OVERWRITE_IGNORED = 0x80000
    CONFLICT_STYLE_MERGE = 0x100000
    CONFLICT_STYLE_DIFF3 = 0x200000
    DONT_REMOVE_EXISTING = 0x400000
    DONT_WRITE_INDEX = 0x800000
    DRY_RUN = 0x1000000
    CONFLICT_STYLE_ZDIFF3 = 0x200000

class ConfigLevel(IntEnum):
    PROGRAMDATA = 1
    SYSTEM = 2
    XDG = 3
    GLOBAL = 4
    LOCAL = 5
    WORKTREE = 6
    APP = 7
    HIGHEST_LEVEL = -1

class CredentialType(IntFlag):
    USERPASS_PLAINTEXT = 0x1
    SSH_KEY = 0x2
    SSH_CUSTOM = 0x4
    DEFAULT = 0x8
    SSH_INTERACTIVE = 0x10
    USERNAME = 0x20
    SSH_MEMORY = 0x40

class DeltaStatus(IntEnum):
    UNMODIFIED = 0
    ADDED = 1
    DELETED = 2
    MODIFIED = 3
    RENAMED = 4
    COPIED = 5
    IGNORED = 6
    UNTRACKED = 7
    TYPECHANGE = 8
    UNREADABLE = 9
    CONFLICTED = 10

class DescribeStrategy(IntEnum):
    DEFAULT = 0
    TAGS = 1
    ALL = 2

class DiffFind(IntFlag):
    FIND_BY_CONFIG = 0x0
    FIND_RENAMES = 0x1
    FIND_RENAMES_FROM_REWRITES = 0x2
    FIND_COPIES = 0x4
    FIND_COPIES_FROM_UNMODIFIED = 0x8
    FIND_REWRITES = 0x10
    BREAK_REWRITES = 0x20
    FIND_AND_BREAK_REWRITES = 0x30
    FIND_FOR_UNTRACKED = 0x40
    FIND_ALL = 0xFF
    FIND_IGNORE_LEADING_WHITESPACE = 0x0
    FIND_IGNORE_WHITESPACE = 0x1000
    FIND_DONT_IGNORE_WHITESPACE = 0x2000
    FIND_EXACT_MATCH_ONLY = 0x4000
    BREAK_REWRITES_FOR_RENAMES_ONLY = 0x8000
    FIND_REMOVE_UNMODIFIED = 0x10000

class DiffFlag(IntFlag):
    BINARY = 0x1
    NOT_BINARY = 0x2
    VALID_ID = 0x4
    EXISTS = 0x8
    VALID_SIZE = 0x10

class DiffOption(IntFlag):
    NORMAL = 0x0
    REVERSE = 0x1
    INCLUDE_IGNORED = 0x2
    RECURSE_IGNORED_DIRS = 0x4
    INCLUDE_UNTRACKED = 0x8
    RECURSE_UNTRACKED_DIRS = 0x10
    INCLUDE_UNMODIFIED = 0x20
    INCLUDE_TYPECHANGE = 0x40
    INCLUDE_TYPECHANGE_TREES = 0x80
    IGNORE_FILEMODE = 0x100
    IGNORE_SUBMODULES = 0x200
    IGNORE_CASE = 0x400
    INCLUDE_CASECHANGE = 0x800
    DISABLE_PATHSPEC_MATCH = 0x1000
    SKIP_BINARY_CHECK = 0x2000
    ENABLE_FAST_UNTRACKED_DIRS = 0x4000
    UPDATE_INDEX = 0x8000
    INCLUDE_UNREADABLE = 0x10000
    INCLUDE_UNREADABLE_AS_UNTRACKED = 0x20000
    INDENT_HEURISTIC = 0x40000
    IGNORE_BLANK_LINES = 0x80000
    FORCE_TEXT = 0x100000
    FORCE_BINARY = 0x200000
    IGNORE_WHITESPACE = 0x400000
    IGNORE_WHITESPACE_CHANGE = 0x800000
    IGNORE_WHITESPACE_EOL = 0x1000000
    SHOW_UNTRACKED_CONTENT = 0x2000000
    SHOW_UNMODIFIED = 0x4000000
    PATIENCE = 0x10000000
    MINIMAL = 0x20000000
    SHOW_BINARY = 0x40000000

class DiffStatsFormat(IntFlag):
    NONE = 0x0
    FULL = 0x1
    SHORT = 0x2
    NUMBER = 0x4
    INCLUDE_SUMMARY = 0x8

class Feature(IntFlag):
    THREADS = 0x1
    HTTPS = 0x2
    SSH = 0x4
    NSEC = 0x8

class FetchPrune(IntEnum):
    UNSPECIFIED = 0
    PRUNE = 1
    NO_PRUNE = 2

class FileMode(IntFlag):
    UNREADABLE = 0x0
    TREE = 0x4000
    BLOB = 0x81A4
    BLOB_EXECUTABLE = 0x81ED
    LINK = 0xA000
    COMMIT = 0xE000

class FileStatus(IntFlag):
    CURRENT = 0x0
    INDEX_NEW = 0x1
    INDEX_MODIFIED = 0x2
    INDEX_DELETED = 0x4
    INDEX_RENAMED = 0x8
    INDEX_TYPECHANGE = 0x10
    WT_NEW = 0x80
    WT_MODIFIED = 0x100
    WT_DELETED = 0x200
    WT_TYPECHANGE = 0x400
    WT_RENAMED = 0x800
    WT_UNREADABLE = 0x1000
    IGNORED = 0x4000
    CONFLICTED = 0x8000

class FilterFlag(IntFlag):
    DEFAULT = 0x0
    ALLOW_UNSAFE = 0x1
    NO_SYSTEM_ATTRIBUTES = 0x2
    ATTRIBUTES_FROM_HEAD = 0x4
    ATTRIBUTES_FROM_COMMIT = 0x8

class FilterMode(IntEnum):
    TO_WORKTREE = 0
    SMUDGE = 0
    TO_ODB = 1
    CLEAN = 1

class MergeAnalysis(IntFlag):
    NONE = 0x0
    NORMAL = 0x1
    UP_TO_DATE = 0x2
    FASTFORWARD = 0x4
    UNBORN = 0x8

class MergeFavor(IntEnum):
    NORMAL = 0
    OURS = 1
    THEIRS = 2
    UNION = 3

class MergeFileFlag(IntFlag):
    DEFAULT = 0x0
    STYLE_MERGE = 0x1
    STYLE_DIFF3 = 0x2
    SIMPLIFY_ALNUM = 0x4
    IGNORE_WHITESPACE = 0x8
    IGNORE_WHITESPACE_CHANGE = 0x10
    IGNORE_WHITESPACE_EOL = 0x20
    DIFF_PATIENCE = 0x40
    DIFF_MINIMAL = 0x80
    STYLE_ZDIFF3 = 0x100
    ACCEPT_CONFLICTS = 0x200

class MergeFlag(IntFlag):
    FIND_RENAMES = 0x1
    FAIL_ON_CONFLICT = 0x2
    SKIP_REUC = 0x4
    NO_RECURSIVE = 0x8
    VIRTUAL_BASE = 0x10

class MergePreference(IntFlag):
    NONE = 0x0
    NO_FASTFORWARD = 0x1
    FASTFORWARD_ONLY = 0x2

class ObjectType(IntEnum):
    ANY = -2
    INVALID = -1
    COMMIT = 1
    TREE = 2
    BLOB = 3
    TAG = 4
    OFS_DELTA = 6
    REF_DELTA = 7

class Option(IntEnum):
    GET_MWINDOW_SIZE = 0
    SET_MWINDOW_SIZE = 1
    GET_MWINDOW_MAPPED_LIMIT = 2
    SET_MWINDOW_MAPPED_LIMIT = 3
    GET_SEARCH_PATH = 4
    SET_SEARCH_PATH = 5
    SET_CACHE_OBJECT_LIMIT = 6
    SET_CACHE_MAX_SIZE = 7
    ENABLE_CACHING = 8
    GET_CACHED_MEMORY = 9
    GET_TEMPLATE_PATH = 10
    SET_TEMPLATE_PATH = 11
    SET_SSL_CERT_LOCATIONS = 12
    SET_USER_AGENT = 13
    ENABLE_STRICT_OBJECT_CREATION = 14
    ENABLE_STRICT_SYMBOLIC_REF_CREATION = 15
    SET_SSL_CIPHERS = 16
    GET_USER_AGENT = 17
    ENABLE_OFS_DELTA = 18
    ENABLE_FSYNC_GITDIR = 19
    GET_WINDOWS_SHAREMODE = 20
    SET_WINDOWS_SHAREMODE = 21
    ENABLE_STRICT_HASH_VERIFICATION = 22
    SET_ALLOCATOR = 23
    ENABLE_UNSAVED_INDEX_SAFETY = 24
    GET_PACK_MAX_OBJECTS = 25
    SET_PACK_MAX_OBJECTS = 26
    DISABLE_PACK_KEEP_FILE_CHECKS = 27
    GET_OWNER_VALIDATION = 35
    SET_OWNER_VALIDATION = 36

class ReferenceFilter(IntEnum):
    ALL = 0
    BRANCHES = 1
    TAGS = 2

class ReferenceType(IntFlag):
    INVALID = 0x0
    DIRECT = 0x1
    SYMBOLIC = 0x2
    ALL = 0x3

class RepositoryInitFlag(IntFlag):
    BARE = 0x1
    NO_REINIT = 0x2
    NO_DOTGIT_DIR = 0x4
    MKDIR = 0x8
    MKPATH = 0x10
    EXTERNAL_TEMPLATE = 0x20
    RELATIVE_GITLINK = 0x40

class RepositoryInitMode(IntEnum):
    SHARED_UMASK = 0
    SHARED_GROUP = 1533
    SHARED_ALL = 1535

class RepositoryOpenFlag(IntFlag):
    DEFAULT = 0x0
    NO_SEARCH = 0x1
    CROSS_FS = 0x2
    BARE = 0x4
    NO_DOTGIT = 0x8
    FROM_ENV = 0x10

class RepositoryState(IntEnum):
    NONE = 0
    MERGE = 1
    REVERT = 2
    REVERT_SEQUENCE = 3
    CHERRYPICK = 4
    CHERRYPICK_SEQUENCE = 5
    BISECT = 6
    REBASE = 7
    REBASE_INTERACTIVE = 8
    REBASE_MERGE = 9
    APPLY_MAILBOX = 10
    APPLY_MAILBOX_OR_REBASE = 11

class ResetMode(IntEnum):
    SOFT = 1
    MIXED = 2
    HARD = 3

class RevSpecFlag(IntFlag):
    SINGLE = 0x1
    RANGE = 0x2
    MERGE_BASE = 0x4

class SortMode(IntFlag):
    NONE = 0x0
    TOPOLOGICAL = 0x1
    TIME = 0x2
    REVERSE = 0x4

class StashApplyProgress(IntEnum):
    NONE = 0
    LOADING_STASH = 1
    ANALYZE_INDEX = 2
    ANALYZE_MODIFIED = 3
    ANALYZE_UNTRACKED = 4
    CHECKOUT_UNTRACKED = 5
    CHECKOUT_MODIFIED = 6
    DONE = 7

class SubmoduleIgnore(IntEnum):
    UNSPECIFIED = -1
    NONE = 1
    UNTRACKED = 2
    DIRTY = 3
    ALL = 4

class SubmoduleStatus(IntFlag):
    IN_HEAD = 0x1
    IN_INDEX = 0x2
    IN_CONFIG = 0x4
    IN_WD = 0x8
    INDEX_ADDED = 0x10
    INDEX_DELETED = 0x20
    INDEX_MODIFIED = 0x40
    WD_UNINITIALIZED = 0x80
    WD_ADDED = 0x100
    WD_DELETED = 0x200
    WD_MODIFIED = 0x400
    WD_INDEX_MODIFIED = 0x800
    WD_WD_MODIFIED = 0x1000
    WD_UNTRACKED = 0x2000



from _typeshed import Incomplete
from typing import TypedDict

from braintree.util.http import Http

class _ValidationErrors(TypedDict):
    errors: Incomplete

class GraphQLClient(Http):
    @staticmethod
    def raise_exception_for_graphql_error(response) -> None: ...
    graphql_headers: dict[str, str]
    def __init__(self, config: Incomplete | None = None, environment: Incomplete | None = None) -> None: ...
    def query(self, definition, variables: Incomplete | None = None, operation_name: Incomplete | None = None): ...
    @staticmethod
    def get_validation_errors(response) -> _ValidationErrors | None: ...
    @staticmethod
    def get_validation_error_code(error) -> Incomplete | None: ...



from collections.abc import MutableSequence
from subprocess import _ENV

def spawn(
    cmd: MutableSequence[str], search_path: bool = True, verbose: bool = False, dry_run: bool = False, env: _ENV | None = None
) -> None: ...
def find_executable(executable: str, path: str | None = None) -> str | None: ...



from docutils import nodes
from docutils.parsers.rst import Directive

class BaseAdmonition(Directive):
    node_class: type[nodes.Admonition]  # Subclasses must set this to the appropriate admonition node class.

class Admonition(BaseAdmonition): ...
class Attention(BaseAdmonition): ...
class Caution(BaseAdmonition): ...
class Danger(BaseAdmonition): ...
class Error(BaseAdmonition): ...
class Hint(BaseAdmonition): ...
class Important(BaseAdmonition): ...
class Note(BaseAdmonition): ...
class Tip(BaseAdmonition): ...
class Warning(BaseAdmonition): ...



from networkx.utils.backends import _dispatchable

@_dispatchable
def degree_centrality(G, nodes): ...
@_dispatchable
def betweenness_centrality(G, nodes): ...
@_dispatchable
def closeness_centrality(G, nodes, normalized: bool = True): ...



from _typeshed import Incomplete
from collections.abc import Generator

from corus.record import Record

class LRWCRecord(Record):
    __attributes__: Incomplete
    hyponym: Incomplete
    hypernym: Incomplete
    genitive: Incomplete
    judgement: Incomplete
    confidence: Incomplete
    def __init__(self, hyponym, hypernym, genitive, judgement, confidence) -> None: ...

def parse_judgement(value): ...
def parse_confidence(value): ...
def parse_toloka_lrwc(lines) -> Generator[Incomplete]: ...
def load_toloka_lrwc(path): ...

class RuADReCTRecord(Record):
    __attributes__: Incomplete
    tweet_id: Incomplete
    tweet: Incomplete
    label: Incomplete
    def __init__(self, tweet_id, tweet, label) -> None: ...

def parse_ruadrect(lines) -> Generator[Incomplete]: ...
def load_ruadrect(path): ...



from _typeshed import Incomplete

from corus.record import Record

__all__ = ["load_morphoru_gicrya", "load_morphoru_rnc", "load_morphoru_corpora"]

class MorphoSent(Record):
    __attributes__: Incomplete
    tokens: Incomplete
    attrs: Incomplete
    def __init__(self, tokens, attrs=()) -> None: ...

class MorphoToken(Record):
    __attributes__: Incomplete
    text: Incomplete
    lemma: Incomplete
    pos: Incomplete
    feats: Incomplete
    feats2: Incomplete
    def __init__(self, text, lemma, pos, feats, feats2: Incomplete | None = None) -> None: ...

def load_morphoru_gicrya(path): ...
def load_morphoru_rnc(path): ...
def load_morphoru_corpora(path): ...



from _typeshed import Incomplete

__all__ = ["load_taiga_arzamas_metas", "load_taiga_arzamas"]

def load_taiga_arzamas_metas(path, offset: int = 0, count: int = 1): ...
def load_taiga_arzamas(path, metas: Incomplete | None = None, offset: int = 144896, count: int = 311): ...



from _typeshed import Incomplete
from collections.abc import Iterator
from dataclasses import dataclass

from networkx.utils.backends import _dispatchable

__all__ = [
    "branching_weight",
    "greedy_branching",
    "maximum_branching",
    "minimum_branching",
    "maximum_spanning_arborescence",
    "minimum_spanning_arborescence",
    "ArborescenceIterator",
]

@_dispatchable
def branching_weight(G, attr: str = "weight", default: float = 1): ...
@_dispatchable
def greedy_branching(G, attr: str = "weight", default: float = 1, kind: str = "max", seed: Incomplete | None = None): ...
@_dispatchable
def maximum_branching(
    G, attr: str = "weight", default: float = 1, preserve_attrs: bool = False, partition: Incomplete | None = None
): ...
@_dispatchable
def minimum_branching(
    G, attr: str = "weight", default: float = 1, preserve_attrs: bool = False, partition: Incomplete | None = None
): ...
@_dispatchable
def maximum_spanning_arborescence(
    G, attr: str = "weight", default: float = 1, preserve_attrs: bool = False, partition: Incomplete | None = None
): ...
@_dispatchable
def minimum_spanning_arborescence(
    G, attr: str = "weight", default: float = 1, preserve_attrs: bool = False, partition: Incomplete | None = None
): ...

class ArborescenceIterator:
    @dataclass
    class Partition:
        mst_weight: float
        partition_dict: dict[Incomplete, Incomplete]

    G: Incomplete
    weight: Incomplete
    minimum: Incomplete
    method: Incomplete
    partition_key: str
    init_partition: Incomplete
    def __init__(self, G, weight: str = "weight", minimum: bool = True, init_partition: Incomplete | None = None) -> None: ...
    partition_queue: Incomplete
    def __iter__(self) -> Iterator[Incomplete]: ...
    def __next__(self): ...



from networkx.utils.backends import _dispatchable

@_dispatchable
def union_all(graphs, rename=()): ...
@_dispatchable
def disjoint_union_all(graphs): ...
@_dispatchable
def compose_all(graphs): ...
@_dispatchable
def intersection_all(graphs): ...



from _typeshed import Incomplete

from authlib.oauth2.rfc7591 import ClientMetadataClaims

class ClientRegistrationEndpoint:
    ENDPOINT_NAME: str
    claims_class = ClientMetadataClaims
    software_statement_alg_values_supported: Incomplete
    server: Incomplete
    def __init__(self, server) -> None: ...
    def __call__(self, request): ...
    def create_registration_response(self, request): ...
    def extract_client_metadata(self, request): ...
    def extract_software_statement(self, software_statement, request): ...
    def get_claims_options(self): ...
    def generate_client_info(self): ...
    def generate_client_registration_info(self, client, request) -> None: ...
    def create_endpoint_request(self, request): ...
    def generate_client_id(self): ...
    def generate_client_secret(self): ...
    def get_server_metadata(self) -> None: ...
    def authenticate_token(self, request) -> None: ...
    def resolve_public_key(self, request) -> None: ...
    def save_client(self, client_info, client_metadata, request) -> None: ...



from _typeshed import Incomplete

def prepare_headers(oauth_params, headers: Incomplete | None = None, realm: Incomplete | None = None): ...
def prepare_form_encoded_body(oauth_params, body): ...
def prepare_request_uri_query(oauth_params, uri): ...



from _typeshed import Incomplete

from corus.record import Record

__all__ = ["load_russe_hj", "load_russe_rt", "load_russe_ae"]

class RusseSemRecord(Record):
    __attributes__: Incomplete
    word1: Incomplete
    word2: Incomplete
    sim: Incomplete
    def __init__(self, word1, word2, sim) -> None: ...

def load_russe_hj(path): ...
def load_russe_rt(path): ...
def load_russe_ae(path): ...



from _typeshed import Incomplete

from corus.record import Record

__all__ = ["load_buriy_news", "load_buriy_webhose"]

class BuriyRecord(Record):
    __attributes__: Incomplete
    timestamp: Incomplete
    url: Incomplete
    edition: Incomplete
    topics: Incomplete
    title: Incomplete
    text: Incomplete
    def __init__(self, timestamp, url, edition, topics, title, text) -> None: ...

def load_buriy_news(path): ...
def load_buriy_webhose(path): ...



from _typeshed import Incomplete

from networkx.utils.backends import _dispatchable

@_dispatchable
def spectral_graph_forge(G, alpha, transformation: str = "identity", seed: Incomplete | None = None): ...



from _typeshed import Incomplete

def sign_jwt_bearer_assertion(
    key,
    issuer,
    audience,
    subject: Incomplete | None = None,
    issued_at: Incomplete | None = None,
    expires_at: Incomplete | None = None,
    claims: Incomplete | None = None,
    header: Incomplete | None = None,
    **kwargs,
): ...
def client_secret_jwt_sign(
    client_secret, client_id, token_endpoint, alg: str = "HS256", claims: Incomplete | None = None, **kwargs
): ...
def private_key_jwt_sign(
    private_key, client_id, token_endpoint, alg: str = "RS256", claims: Incomplete | None = None, **kwargs
): ...



from _typeshed import Incomplete

from jwcrypto.common import JWException

JWSHeaderRegistry: Incomplete
default_allowed_algs: Incomplete

class InvalidJWSSignature(JWException):
    def __init__(self, message: str | None = None, exception: BaseException | None = None) -> None: ...

class InvalidJWSObject(JWException):
    def __init__(self, message: str | None = None, exception: BaseException | None = None) -> None: ...

class InvalidJWSOperation(JWException):
    def __init__(self, message: str | None = None, exception: BaseException | None = None) -> None: ...

class JWSCore:
    alg: Incomplete
    engine: Incomplete
    key: Incomplete
    header: Incomplete
    protected: Incomplete
    payload: Incomplete
    def __init__(self, alg, key, header, payload, algs: Incomplete | None = None) -> None: ...
    def sign(self): ...
    def verify(self, signature): ...

class JWS:
    objects: Incomplete
    verifylog: Incomplete
    header_registry: Incomplete
    def __init__(self, payload: Incomplete | None = None, header_registry: Incomplete | None = None) -> None: ...
    @property
    def allowed_algs(self): ...
    @allowed_algs.setter
    def allowed_algs(self, algs) -> None: ...
    @property
    def is_valid(self): ...
    def verify(self, key, alg: Incomplete | None = None, detached_payload: Incomplete | None = None) -> None: ...
    def deserialize(self, raw_jws, key: Incomplete | None = None, alg: Incomplete | None = None) -> None: ...
    def add_signature(
        self, key, alg: Incomplete | None = None, protected: Incomplete | None = None, header: Incomplete | None = None
    ) -> None: ...
    def serialize(self, compact: bool = False): ...
    @property
    def payload(self): ...
    def detach_payload(self) -> None: ...
    @property
    def jose_header(self): ...
    @classmethod
    def from_jose_token(cls, token): ...
    def __eq__(self, other: object) -> bool: ...



from _typeshed import Incomplete
from collections.abc import Generator

from corus.record import Record

class ArchiveRecord(Record):
    __attributes__: Incomplete
    name: Incomplete
    offset: Incomplete
    file: Incomplete
    def __init__(self, name, offset, file) -> None: ...

class TaigaRecord(Record):
    __attributes__: Incomplete
    id: Incomplete
    meta: Incomplete
    text: Incomplete
    def __init__(self, id, meta, text) -> None: ...

class Author(Record):
    __attributes__: Incomplete
    name: Incomplete
    readers: Incomplete
    texts: Incomplete
    profession: Incomplete
    about: Incomplete
    url: Incomplete
    def __init__(
        self,
        name,
        readers: Incomplete | None = None,
        texts: Incomplete | None = None,
        profession: Incomplete | None = None,
        about: Incomplete | None = None,
        url: Incomplete | None = None,
    ) -> None: ...

class Meta(Record):
    __attributes__: Incomplete
    id: Incomplete
    timestamp: Incomplete
    tags: Incomplete
    themes: Incomplete
    rubric: Incomplete
    genre: Incomplete
    topic: Incomplete
    author: Incomplete
    lang: Incomplete
    title: Incomplete
    url: Incomplete
    def __init__(
        self,
        id,
        timestamp: Incomplete | None = None,
        tags: Incomplete | None = None,
        themes: Incomplete | None = None,
        rubric: Incomplete | None = None,
        genre: Incomplete | None = None,
        topic: Incomplete | None = None,
        author: Incomplete | None = None,
        lang: Incomplete | None = None,
        title: Incomplete | None = None,
        url: Incomplete | None = None,
    ) -> None: ...

def load_tar(path, offset: int = 0) -> Generator[Incomplete]: ...
def load_zip(path, offset: int = 0) -> Generator[Incomplete]: ...
def parse_meta(file, encoding: str = "utf8") -> Generator[Incomplete]: ...
def load_metas(path, pattern, offset, count, load) -> Generator[Incomplete]: ...
def load_tar_metas(path, pattern, offset, count): ...
def load_zip_metas(path, pattern, offset, count): ...
def load_texts(path, pattern, offset, count, parse_id, load, encoding: str = "utf8") -> Generator[Incomplete]: ...
def parse_filename_id(path): ...
def load_tar_texts(path, pattern, offset, count, parse_id=...): ...
def load_zip_texts(path, pattern, offset, count, parse_id=...): ...
def merge_metas(records, metas: Incomplete | None = None) -> Generator[Incomplete]: ...
def patch_month(date, months): ...



from _typeshed import Incomplete
from collections.abc import Generator

def match_names(records, pattern) -> Generator[Incomplete]: ...
def rstrip(text): ...
def load_text(path): ...
def dump_text(text, path) -> None: ...
def load_lines(path, encoding: str = "utf-8") -> Generator[Incomplete]: ...
def parse_xml(text): ...
def load_z_lines(path, open, encoding: str = "utf8") -> Generator[Incomplete]: ...
def load_gz_lines(path): ...
def load_bz2_lines(path): ...
def load_xz_lines(path): ...
def list_zip(path): ...
def load_zip_lines(path, name, encoding: str = "utf8") -> Generator[Incomplete]: ...
def load_zip_texts(path, names, encoding: str = "utf8") -> Generator[Incomplete]: ...
def parse_csv(lines, delimiter: str = ",", max_field: Incomplete | None = None): ...
def parse_tsv(lines): ...
def skip_header(rows): ...
def dict_csv(rows) -> Generator[Incomplete]: ...
def parse_jsonl(lines) -> Generator[Incomplete]: ...



from networkx.utils.backends import _dispatchable

@_dispatchable
def subgraph_centrality_exp(G): ...
@_dispatchable
def subgraph_centrality(G): ...
@_dispatchable
def communicability_betweenness_centrality(G): ...
@_dispatchable
def estrada_index(G): ...



from braintree.graphql.inputs.create_customer_session_input import CreateCustomerSessionInput as CreateCustomerSessionInput
from braintree.graphql.inputs.customer_recommendations_input import CustomerRecommendationsInput as CustomerRecommendationsInput
from braintree.graphql.inputs.customer_session_input import CustomerSessionInput as CustomerSessionInput
from braintree.graphql.inputs.phone_input import PhoneInput as PhoneInput
from braintree.graphql.inputs.update_customer_session_input import UpdateCustomerSessionInput as UpdateCustomerSessionInput



from _typeshed import Incomplete

from braintree.graphql.types.payment_options import PaymentOptions

class CustomerRecommendations:
    payment_options: Incomplete
    def __init__(self, payment_options: list[PaymentOptions]) -> None: ...



from _typeshed import Incomplete

def add_to_uri(token, uri): ...
def add_to_headers(token, headers: Incomplete | None = None): ...
def add_to_body(token, body: Incomplete | None = None): ...
def add_bearer_token(token, uri, headers, body, placement: str = "header"): ...



from _typeshed import Incomplete
from collections.abc import Generator

from corus.record import Record
from corus.third.WikiExtractor import Extractor

class WikiRecord(Record):
    __attributes__: Incomplete
    id: Incomplete
    url: Incomplete
    title: Incomplete
    text: Incomplete
    def __init__(self, id, url, title, text) -> None: ...
    @classmethod
    def from_json(cls, data): ...

class Extractor_(Extractor):
    def extract_(self): ...

def load_wiki(path) -> Generator[Incomplete]: ...



from _typeshed import Incomplete
from collections.abc import Generator

from corus.record import Record

__all__ = ["load_taiga_social"]

class TaigaSocialRecord(Record):
    __attributes__: Incomplete
    id: Incomplete
    network: Incomplete
    text: Incomplete
    def __init__(self, id, network, text) -> None: ...

def load_taiga_social(path, offset: int = 3985892864, count: int = 4) -> Generator[Incomplete]: ...



from _typeshed import Incomplete
from collections.abc import Generator

COMMANDS: Incomplete
KB: int
MB: Incomplete
GB: Incomplete
LABELS: Incomplete

def is_command(step, commands=("wget", "unzip", "unrar", "rm", "mv", "tar")): ...
def format_bytes(value): ...
def format_count(value): ...
def unfold_metas(items) -> Generator[Incomplete]: ...
def format_metas_(metas, nbviewer: Incomplete | None = None) -> Generator[Incomplete]: ...
def format_metas(metas, url: Incomplete | None = None): ...
def show_html(html) -> None: ...
def patch_readme(html, path) -> None: ...



from _typeshed import Incomplete

__all__ = ["load_taiga_lenta_metas", "load_taiga_lenta"]

def load_taiga_lenta_metas(path, offset: int = 0, count: int = 1): ...
def load_taiga_lenta(path, metas: Incomplete | None = None, offset: int = 12800000, count: int = 36446): ...



from _typeshed import Incomplete

from networkx.utils.backends import _dispatchable

@_dispatchable
def rich_club_coefficient(G, normalized: bool = True, Q: float = 100, seed: Incomplete | None = None): ...



def to_bytes(x, charset: str = "utf-8", errors: str = "strict") -> bytes | None: ...
def to_unicode(x, charset: str = "utf-8", errors: str = "strict") -> str | None: ...
def to_native(x, encoding: str = "ascii"): ...
def json_loads(s): ...
def json_dumps(data, ensure_ascii: bool = False): ...
def urlsafe_b64decode(s): ...
def urlsafe_b64encode(s): ...
def base64_to_int(s): ...
def int_to_base64(num): ...
def json_b64encode(text): ...



from _typeshed import Incomplete

from corus.record import Record

__all__ = ["load_ud_gsd", "load_ud_taiga", "load_ud_pud", "load_ud_syntag"]

class UDSent(Record):
    __attributes__: Incomplete
    id: Incomplete
    text: Incomplete
    attrs: Incomplete
    tokens: Incomplete
    def __init__(self, id, text, attrs, tokens) -> None: ...

class UDToken(Record):
    __attributes__: Incomplete
    id: Incomplete
    text: Incomplete
    lemma: Incomplete
    pos: Incomplete
    feats: Incomplete
    head_id: Incomplete
    rel: Incomplete
    def __init__(self, id, text, lemma, pos, feats, head_id, rel) -> None: ...

def load_ud_gsd(path): ...
def load_ud_taiga(path): ...
def load_ud_pud(path): ...
def load_ud_syntag(path): ...



from _typeshed import Incomplete
from collections.abc import Generator

from corus.record import Record

RU: str
BG: str
CS: str
PL: str
LANGS: Incomplete
ANNOTATED: str
RAW: str
TXT: str
OUT: str

class BsnlpId(Record):
    __attributes__: Incomplete
    lang: Incomplete
    type: Incomplete
    name: Incomplete
    path: Incomplete
    def __init__(self, lang, type, name, path) -> None: ...

class BsnlpRaw(Record):
    __attributes__: Incomplete
    id: Incomplete
    name: Incomplete
    lang: Incomplete
    date: Incomplete
    url: Incomplete
    text: Incomplete
    def __init__(self, id, name, lang, date, url, text) -> None: ...

class BsnlpAnnotated(Record):
    __attributes__: Incomplete
    id: Incomplete
    name: Incomplete
    substrings: Incomplete
    def __init__(self, id, name, substrings) -> None: ...

class BsnlpSubstring(Record):
    __attributes__: Incomplete
    text: Incomplete
    normal: Incomplete
    type: Incomplete
    id: Incomplete
    def __init__(self, text, normal, type, id) -> None: ...

class BsnlpMarkup(Record):
    __attributes__: Incomplete
    id: Incomplete
    name: Incomplete
    lang: Incomplete
    date: Incomplete
    url: Incomplete
    text: Incomplete
    substrings: Incomplete
    def __init__(self, id, name, lang, date, url, text, substrings) -> None: ...

def walk(dir): ...
def load_ids(dir, langs) -> Generator[Incomplete]: ...
def select_type(ids, type) -> Generator[Incomplete]: ...

RAW_PATTERN: Incomplete

def parse_raw(name, text): ...
def load_raw(records) -> Generator[Incomplete]: ...

ANNOTATED_PATTERN: Incomplete

def parse_substrings(lines) -> Generator[Incomplete]: ...
def parse_annotated(name, lines): ...
def load_annotated(records) -> Generator[Incomplete]: ...
def merge(raw, annotated) -> Generator[Incomplete]: ...
def load_bsnlp(dir, langs=["ru"]): ...



from _typeshed import Incomplete

__all__ = ["load_taiga_kp_metas", "load_taiga_kp"]

def load_taiga_kp_metas(path, offset: int = 0, count: int = 1): ...
def load_taiga_kp(path, metas: Incomplete | None = None, offset: int = 13042176, count: int = 45503): ...



from _typeshed import Incomplete

from braintree.graphql.enums.recommendations import Recommendations
from braintree.graphql.inputs.customer_session_input import CustomerSessionInput

class CustomerRecommendationsInput:
    def __init__(
        self,
        session_id: str,
        recommendations: list[Recommendations],
        merchant_account_id: str | None = None,
        customer: CustomerSessionInput | None = None,
    ) -> None: ...
    def to_graphql_variables(self) -> dict[Incomplete, Incomplete]: ...
    @staticmethod
    def builder(session_id: str, recommendations: list[Recommendations]): ...

    class Builder:
        def __init__(self, session_id: str, recommendations: list[Recommendations]) -> None: ...
        def merchant_account_id(self, merchant_account_id: str): ...
        def customer(self, customer: CustomerSessionInput): ...
        def build(self): ...



import logging
import typing as t
from typing_extensions import TypeAlias

import click

_AnyCallable: TypeAlias = t.Callable[..., t.Any]
_FC = t.TypeVar("_FC", bound=_AnyCallable | click.Command)

def simple_verbosity_option(
    logger: logging.Logger | str | None = None, *names: str, **kwargs: t.Any
) -> t.Callable[[_FC], _FC]: ...



from _typeshed import Incomplete

from networkx.utils.backends import _dispatchable

@_dispatchable
def line_graph(G, create_using: Incomplete | None = None): ...
@_dispatchable
def inverse_line_graph(G): ...



from collections.abc import Iterable

from networkx.classes.graph import Graph, _Edge, _Node
from networkx.utils.backends import _dispatchable

@_dispatchable
def betweenness_centrality_subset(
    G: Graph[_Node], sources: Iterable[_Node], targets: Iterable[_Node], normalized: bool = False, weight: str | None = None
) -> dict[_Node, float]: ...
@_dispatchable
def edge_betweenness_centrality_subset(
    G: Graph[_Node], sources: Iterable[_Node], targets: Iterable[_Node], normalized: bool = False, weight: str | None = None
) -> dict[_Edge[_Node], float]: ...



import click

def get_form_for(command_path: str) -> str: ...
def _get_commands_by_path(command_path: str) -> list[tuple[click.Context, click.Command]]: ...
def _generate_form_data(ctx_and_commands: list[tuple[click.Context, click.Command]]): ...
def _process_help(help_text: bool) -> str: ...



from _typeshed import Incomplete

class BaseClaims(dict[str, object]):
    REGISTERED_CLAIMS: Incomplete
    header: Incomplete
    options: Incomplete
    params: Incomplete
    def __init__(self, payload, header, options: Incomplete | None = None, params: Incomplete | None = None) -> None: ...
    def __getattr__(self, key): ...
    def get_registered_claims(self): ...

class JWTClaims(BaseClaims):
    REGISTERED_CLAIMS: Incomplete
    def validate(self, now: Incomplete | None = None, leeway: int = 0) -> None: ...
    def validate_iss(self) -> None: ...
    def validate_sub(self) -> None: ...
    def validate_aud(self) -> None: ...
    def validate_exp(self, now, leeway) -> None: ...
    def validate_nbf(self, now, leeway) -> None: ...
    def validate_iat(self, now, leeway) -> None: ...
    def validate_jti(self) -> None: ...



from _typeshed import Incomplete
from collections.abc import Generator

from corus.record import Record

class RuDReCRecord(Record):
    __attributes__: Incomplete
    file_name: Incomplete
    text: Incomplete
    sentence_id: Incomplete
    entities: Incomplete
    def __init__(self, file_name, text, sentence_id, entities) -> None: ...

class RuDReCEntity(Record):
    __attributes__: Incomplete
    entity_id: Incomplete
    entity_text: Incomplete
    entity_type: Incomplete
    start: Incomplete
    end: Incomplete
    concept_id: Incomplete
    concept_name: Incomplete
    def __init__(self, entity_id, entity_text, entity_type, start, end, concept_id, concept_name) -> None: ...

def parse_entities(items) -> Generator[Incomplete]: ...
def parse_rudrec(items) -> Generator[Incomplete]: ...
def load_rudrec(path): ...



from _typeshed import Incomplete
from collections.abc import Generator

from corus.record import Record

DEVSET: str
TESTSET: str
TXT: str
SPANS: str
OBJECTS: str
COREF: str
FACTS: str

class FactruSpan(Record):
    __attributes__: Incomplete
    id: Incomplete
    type: Incomplete
    start: Incomplete
    stop: Incomplete
    def __init__(self, id, type, start, stop) -> None: ...

class FactruObject(Record):
    __attributes__: Incomplete
    id: Incomplete
    type: Incomplete
    spans: Incomplete
    def __init__(self, id, type, spans) -> None: ...

class FactruCorefSlot(Record):
    __attributes__: Incomplete
    type: Incomplete
    value: Incomplete
    def __init__(self, type, value) -> None: ...

class FactruCoref(Record):
    __attributes__: Incomplete
    id: Incomplete
    objects: Incomplete
    slots: Incomplete
    def __init__(self, id, objects, slots) -> None: ...

class FactruFactSlot(Record):
    __attributes__: Incomplete
    type: Incomplete
    ref: Incomplete
    value: Incomplete
    def __init__(self, type, ref, value) -> None: ...

class FactruFact(Record):
    __attributes__: Incomplete
    id: Incomplete
    type: Incomplete
    slots: Incomplete
    def __init__(self, id, type, slots) -> None: ...

class FactruMarkup(Record):
    __attributes__: Incomplete
    id: Incomplete
    text: Incomplete
    objects: Incomplete
    corefs: Incomplete
    facts: Incomplete
    def __init__(self, id, text, objects, corefs, facts) -> None: ...

def list_ids(dir, set) -> Generator[Incomplete]: ...
def part_path(id, dir, set, part): ...
def parse_spans(lines) -> Generator[Incomplete]: ...
def parse_objects(lines, spans) -> Generator[Incomplete]: ...
def parse_coref_slots(lines) -> Generator[Incomplete]: ...
def parse_corefs(lines, objects) -> Generator[Incomplete]: ...
def parse_facts_slots(lines, id_corefs, id_spans) -> Generator[Incomplete]: ...
def parse_facts(lines, corefs, spans) -> Generator[Incomplete]: ...
def load_id(id, dir, set): ...
def load_factru(dir, sets=["devset", "testset"]) -> Generator[Incomplete]: ...



from _typeshed import Incomplete
from collections.abc import Generator

from corus.record import Record

class GareevToken(Record):
    __attributes__: Incomplete
    text: Incomplete
    tag: Incomplete
    def __init__(self, text, tag) -> None: ...

class GareevRecord(Record):
    __attributes__: Incomplete
    tokens: Incomplete
    def __init__(self, tokens) -> None: ...

def parse_conll(lines) -> Generator[Incomplete]: ...
def parse_gareev(lines): ...
def load_id(id, dir): ...
def list_ids(dir) -> Generator[Incomplete]: ...
def load_gareev(dir) -> Generator[Incomplete]: ...



from _typeshed import Incomplete

class Record:
    __attributes__: Incomplete
    def __eq__(self, other): ...
    def __ne__(self, other): ...
    def __iter__(self): ...
    def __hash__(self): ...



from _typeshed import Incomplete
from collections.abc import Generator

from networkx.utils.backends import _dispatchable

@_dispatchable
def nonisomorphic_trees(order, create: str = "graph") -> Generator[Incomplete, None, None]: ...
@_dispatchable
def number_of_nonisomorphic_trees(order): ...



from _typeshed import Incomplete
from collections.abc import Generator

from corus.record import Record

class LibrusecRecord(Record):
    __attributes__: Incomplete
    id: Incomplete
    text: Incomplete
    def __init__(self, id, text) -> None: ...

def flush(id, buffer): ...
def parse_librusec(lines) -> Generator[Incomplete]: ...
def load_librusec(path): ...



from .bsnlp import load_bsnlp as load_bsnlp
from .buriy import *
from .corpora import load_corpora as load_corpora
from .factru import load_factru as load_factru
from .gareev import load_gareev as load_gareev
from .gramru import load_gramru as load_gramru
from .lenta import load_lenta as load_lenta, load_lenta2 as load_lenta2
from .librusec import load_librusec as load_librusec
from .mokoron import *
from .morphoru import *
from .ne5 import load_ne5 as load_ne5
from .ods import *
from .omnia import load_omnia as load_omnia
from .persons import load_persons as load_persons
from .ria import *
from .rudrec import load_rudrec as load_rudrec
from .russe import *
from .simlex import load_simlex as load_simlex
from .taiga import *
from .toloka import load_ruadrect as load_ruadrect, load_toloka_lrwc as load_toloka_lrwc
from .ud import *
from .wiki import load_wiki as load_wiki
from .wikiner import load_wikiner as load_wikiner



from networkx.utils.backends import _dispatchable

@_dispatchable
def is_arborescence(G): ...
@_dispatchable
def is_branching(G): ...
@_dispatchable
def is_forest(G): ...
@_dispatchable
def is_tree(G): ...



from _typeshed import Incomplete
from typing import Final

__version__: Final[str]

# NOTE: All the attributes in this module are Final
#       rl_config is the place to make changes
allowTableBoundsErrors: Final[int]
shapeChecking: Final[int]
defaultEncoding: Final[str]
defaultGraphicsFontName: Final[str]
pageCompression: Final[int]
useA85: Final[int]
defaultPageSize: Final[str]
defaultImageCaching: Final[int]
warnOnMissingFontGlyphs: Final[int]
verbose: Final[int]
showBoundary: Final[int]
emptyTableAction: Final[str]
invariant: Final[int]
eps_preview_transparent: Final[Incomplete]
eps_preview: Final[int]
eps_ttf_embed: Final[int]
eps_ttf_embed_uid: Final[int]
overlapAttachedSpace: Final[int]
longTableOptimize: Final[int]
autoConvertEncoding: Final[int]
_FUZZ: Final[float]
wrapA85: Final[int]
fsEncodings: Final[Incomplete]
odbc_driver: Final[str]
platypus_link_underline: Final[int]
canvas_basefontname: Final[str]
allowShortTableRows: Final[int]
imageReaderFlags: Final[int]
paraFontSizeHeightOffset: Final[int]
canvas_baseColor: Final[Incomplete]
ignoreContainerActions: Final[int]
ttfAsciiReadable: Final[int]
pdfMultiLine: Final[int]
pdfComments: Final[int]
debug: Final[int]
rtlSupport: Final[int]
listWrapOnFakeWidth: Final[int]
underlineWidth: Final[str]
underlineOffset: Final[str]
underlineGap: Final[str]
strikeWidth: Final[str]
strikeOffset: Final[str]
strikeGap: Final[str]
decimalSymbol: Final[str]
errorOnDuplicatePageLabelPage: Final[int]
autoGenerateMissingTTFName: Final[int]
allowTTFSubsetting: Final[Incomplete]
spaceShrinkage: Final[float]
hyphenationLang: Final[str]
uriWasteReduce: Final[int]
embeddedHyphenation: Final[int]
hyphenationMinWordLength: Final[int]
reserveTTFNotdef: Final[int]
documentLang: Final[Incomplete]
encryptionStrength: Final[int]
trustedHosts: Final[Incomplete]
trustedSchemes: Final[Incomplete]
renderPMBackend: Final[str]
xmlParser: Final[str]
textPaths: Final[str]
toColorCanUse: Final[str]
defCWRF: Final[float]
T1SearchPath: Final[Incomplete]
TTFSearchPath: Final[Incomplete]
CMapSearchPath: Final[Incomplete]
shapedFontGlob: Final[Incomplete | None]



from _typeshed import Incomplete
from collections.abc import Generator

from corus.record import Record

class LentaRecord(Record):
    __attributes__: Incomplete
    url: Incomplete
    title: Incomplete
    text: Incomplete
    topic: Incomplete
    tags: Incomplete
    date: Incomplete
    def __init__(self, url, title, text, topic, tags, date: Incomplete | None = None) -> None: ...

def parse_lenta(lines) -> Generator[Incomplete]: ...
def parse_lenta2(lines) -> Generator[Incomplete]: ...
def load_lenta(path): ...
def load_lenta2(path): ...



from _typeshed import Incomplete

from docutils.writers import _WriterParts

__docformat__: str

class Publisher:
    document: Incomplete
    reader: Incomplete
    parser: Incomplete
    writer: Incomplete
    source: Incomplete
    source_class: Incomplete
    destination: Incomplete
    destination_class: Incomplete
    settings: Incomplete
    def __init__(
        self,
        reader: Incomplete | None = None,
        parser: Incomplete | None = None,
        writer: Incomplete | None = None,
        source: Incomplete | None = None,
        source_class=...,
        destination: Incomplete | None = None,
        destination_class=...,
        settings: Incomplete | None = None,
    ) -> None: ...
    def set_reader(self, reader_name, parser, parser_name) -> None: ...
    def set_writer(self, writer_name) -> None: ...
    def set_components(self, reader_name, parser_name, writer_name) -> None: ...
    def setup_option_parser(
        self,
        usage: Incomplete | None = None,
        description: Incomplete | None = None,
        settings_spec: Incomplete | None = None,
        config_section: Incomplete | None = None,
        **defaults,
    ): ...
    def get_settings(
        self,
        usage: Incomplete | None = None,
        description: Incomplete | None = None,
        settings_spec: Incomplete | None = None,
        config_section: Incomplete | None = None,
        **defaults,
    ): ...
    def process_programmatic_settings(self, settings_spec, settings_overrides, config_section) -> None: ...
    def process_command_line(
        self,
        argv: Incomplete | None = None,
        usage: Incomplete | None = None,
        description: Incomplete | None = None,
        settings_spec: Incomplete | None = None,
        config_section: Incomplete | None = None,
        **defaults,
    ) -> None: ...
    def set_io(self, source_path: Incomplete | None = None, destination_path: Incomplete | None = None) -> None: ...
    def set_source(self, source: Incomplete | None = None, source_path: Incomplete | None = None) -> None: ...
    def set_destination(self, destination: Incomplete | None = None, destination_path: Incomplete | None = None) -> None: ...
    def apply_transforms(self) -> None: ...
    def publish(
        self,
        argv: Incomplete | None = None,
        usage: Incomplete | None = None,
        description: Incomplete | None = None,
        settings_spec: Incomplete | None = None,
        settings_overrides: Incomplete | None = None,
        config_section: Incomplete | None = None,
        enable_exit_status: bool = False,
    ): ...
    def debugging_dumps(self) -> None: ...
    def prompt(self) -> None: ...
    def report_Exception(self, error) -> None: ...
    def report_SystemMessage(self, error) -> None: ...
    def report_UnicodeError(self, error) -> None: ...

default_usage: str
default_description: str

def publish_cmdline(
    reader: Incomplete | None = None,
    reader_name: str = "standalone",
    parser: Incomplete | None = None,
    parser_name: str = "restructuredtext",
    writer: Incomplete | None = None,
    writer_name: str = "pseudoxml",
    settings: Incomplete | None = None,
    settings_spec: Incomplete | None = None,
    settings_overrides: Incomplete | None = None,
    config_section: Incomplete | None = None,
    enable_exit_status: bool = True,
    argv: Incomplete | None = None,
    usage=...,
    description=...,
): ...
def publish_file(
    source: Incomplete | None = None,
    source_path: Incomplete | None = None,
    destination: Incomplete | None = None,
    destination_path: Incomplete | None = None,
    reader: Incomplete | None = None,
    reader_name: str = "standalone",
    parser: Incomplete | None = None,
    parser_name: str = "restructuredtext",
    writer: Incomplete | None = None,
    writer_name: str = "pseudoxml",
    settings: Incomplete | None = None,
    settings_spec: Incomplete | None = None,
    settings_overrides: Incomplete | None = None,
    config_section: Incomplete | None = None,
    enable_exit_status: bool = False,
): ...
def publish_string(
    source,
    source_path: Incomplete | None = None,
    destination_path: Incomplete | None = None,
    reader: Incomplete | None = None,
    reader_name: str = "standalone",
    parser: Incomplete | None = None,
    parser_name: str = "restructuredtext",
    writer: Incomplete | None = None,
    writer_name: str = "pseudoxml",
    settings: Incomplete | None = None,
    settings_spec: Incomplete | None = None,
    settings_overrides: Incomplete | None = None,
    config_section: Incomplete | None = None,
    enable_exit_status: bool = False,
): ...
def publish_parts(
    source,
    source_path: Incomplete | None = None,
    source_class=...,
    destination_path: Incomplete | None = None,
    reader: Incomplete | None = None,
    reader_name: str = "standalone",
    parser: Incomplete | None = None,
    parser_name: str = "restructuredtext",
    writer: Incomplete | None = None,
    writer_name: str = "pseudoxml",
    settings: Incomplete | None = None,
    settings_spec: Incomplete | None = None,
    settings_overrides: Incomplete | None = None,
    config_section: Incomplete | None = None,
    enable_exit_status: bool = False,
) -> _WriterParts: ...
def publish_doctree(
    source,
    source_path: Incomplete | None = None,
    source_class=...,
    reader: Incomplete | None = None,
    reader_name: str = "standalone",
    parser: Incomplete | None = None,
    parser_name: str = "restructuredtext",
    settings: Incomplete | None = None,
    settings_spec: Incomplete | None = None,
    settings_overrides: Incomplete | None = None,
    config_section: Incomplete | None = None,
    enable_exit_status: bool = False,
): ...
def publish_from_doctree(
    document,
    destination_path: Incomplete | None = None,
    writer: Incomplete | None = None,
    writer_name: str = "pseudoxml",
    settings: Incomplete | None = None,
    settings_spec: Incomplete | None = None,
    settings_overrides: Incomplete | None = None,
    config_section: Incomplete | None = None,
    enable_exit_status: bool = False,
): ...
def publish_cmdline_to_binary(
    reader: Incomplete | None = None,
    reader_name: str = "standalone",
    parser: Incomplete | None = None,
    parser_name: str = "restructuredtext",
    writer: Incomplete | None = None,
    writer_name: str = "pseudoxml",
    settings: Incomplete | None = None,
    settings_spec: Incomplete | None = None,
    settings_overrides: Incomplete | None = None,
    config_section: Incomplete | None = None,
    enable_exit_status: bool = True,
    argv: Incomplete | None = None,
    usage=...,
    description=...,
    destination: Incomplete | None = None,
    destination_class=...,
): ...
def publish_programmatically(
    source_class,
    source,
    source_path,
    destination_class,
    destination,
    destination_path,
    reader,
    reader_name,
    parser,
    parser_name,
    writer,
    writer_name,
    settings,
    settings_spec,
    settings_overrides,
    config_section,
    enable_exit_status,
): ...
def rst2something(writer, documenttype, doc_path: str = "") -> None: ...
def rst2html() -> None: ...
def rst2html4() -> None: ...
def rst2html5() -> None: ...
def rst2latex() -> None: ...
def rst2man() -> None: ...
def rst2odt() -> None: ...
def rst2pseudoxml() -> None: ...
def rst2s5() -> None: ...
def rst2xetex() -> None: ...
def rst2xml() -> None: ...



from _typeshed import Incomplete
from collections.abc import Sequence
from enum import Enum
from typing import Any, NamedTuple

from cryptography.hazmat.primitives.asymmetric.ed448 import Ed448PrivateKey as Ed448PrivateKey, Ed448PublicKey as Ed448PublicKey
from cryptography.hazmat.primitives.asymmetric.ed25519 import (
    Ed25519PrivateKey as Ed25519PrivateKey,
    Ed25519PublicKey as Ed25519PublicKey,
)
from cryptography.hazmat.primitives.asymmetric.x448 import X448PrivateKey as X448PrivateKey, X448PublicKey as X448PublicKey
from cryptography.hazmat.primitives.asymmetric.x25519 import (
    X25519PrivateKey as X25519PrivateKey,
    X25519PublicKey as X25519PublicKey,
)
from jwcrypto.common import JWException

class UnimplementedOKPCurveKey:
    @classmethod
    def generate(cls) -> None: ...
    @classmethod
    def from_public_bytes(cls, *args) -> None: ...
    @classmethod
    def from_private_bytes(cls, *args) -> None: ...

ImplementedOkpCurves: Sequence[str]
priv_bytes: Incomplete

JWKTypesRegistry: Incomplete

class ParmType(Enum):
    name = "A string with a name"  # pyright: ignore[reportAssignmentType]
    b64 = "Base64url Encoded"
    b64u = "Base64urlUint Encoded"
    unsupported = "Unsupported Parameter"

class JWKParameter(NamedTuple):
    description: Incomplete
    public: Incomplete
    required: Incomplete
    type: Incomplete

JWKValuesRegistry: Incomplete
JWKParamsRegistry: Incomplete
JWKEllipticCurveRegistry: Incomplete
JWKUseRegistry: Incomplete
JWKOperationsRegistry: Incomplete
JWKpycaCurveMap: Incomplete
IANANamedInformationHashAlgorithmRegistry: Incomplete

class InvalidJWKType(JWException):
    value: Incomplete
    def __init__(self, value: Incomplete | None = None) -> None: ...

class InvalidJWKUsage(JWException):
    value: Incomplete
    use: Incomplete
    def __init__(self, use, value) -> None: ...

class InvalidJWKOperation(JWException):
    op: Incomplete
    values: Incomplete
    def __init__(self, operation, values) -> None: ...

class InvalidJWKValue(JWException): ...

class JWK(dict[str, Any]):
    def __init__(self, **kwargs) -> None: ...
    @classmethod
    def generate(cls, **kwargs): ...
    def generate_key(self, **params) -> None: ...
    def import_key(self, **kwargs) -> None: ...
    @classmethod
    def from_json(cls, key): ...
    def export(self, private_key: bool = True, as_dict: bool = False): ...
    def export_public(self, as_dict: bool = False): ...
    def export_private(self, as_dict: bool = False): ...
    def export_symmetric(self, as_dict: bool = False): ...
    def public(self): ...
    @property
    def has_public(self) -> bool: ...
    @property
    def has_private(self) -> bool: ...
    @property
    def is_symmetric(self) -> bool: ...
    @property
    def key_type(self): ...
    @property
    def key_id(self): ...
    @property
    def key_curve(self): ...
    def get_curve(self, arg): ...
    def get_op_key(self, operation: Incomplete | None = None, arg: Incomplete | None = None): ...
    def import_from_pyca(self, key) -> None: ...
    def import_from_pem(self, data, password: Incomplete | None = None, kid: Incomplete | None = None) -> None: ...
    def export_to_pem(self, private_key: bool = False, password: bool = False): ...
    @classmethod
    def from_pyca(cls, key): ...
    @classmethod
    def from_pem(cls, data, password: Incomplete | None = None): ...
    def thumbprint(self, hashalg=...): ...
    def thumbprint_uri(self, hname: str = "sha-256"): ...
    @classmethod
    def from_password(cls, password): ...
    def setdefault(self, key: str, default: Incomplete | None = None): ...

class JWKSet(dict[str, Any]):
    def add(self, elem) -> None: ...
    def export(self, private_keys: bool = True, as_dict: bool = False): ...
    def import_keyset(self, keyset) -> None: ...
    @classmethod
    def from_json(cls, keyset): ...
    def get_key(self, kid): ...
    def get_keys(self, kid): ...
    def setdefault(self, key: str, default: Incomplete | None = None): ...



import datetime
from typing_extensions import TypeAlias

from .cal import Alarm, Event, Todo

__all__ = [
    "Alarms",
    "AlarmTime",
    "IncompleteAlarmInformation",
    "ComponentEndMissing",
    "ComponentStartMissing",
    "LocalTimezoneMissing",
]

Parent: TypeAlias = Event | Todo

class IncompleteAlarmInformation(ValueError): ...
class ComponentStartMissing(IncompleteAlarmInformation): ...
class ComponentEndMissing(IncompleteAlarmInformation): ...
class LocalTimezoneMissing(IncompleteAlarmInformation): ...

class AlarmTime:
    def __init__(
        self,
        alarm: Alarm,
        trigger: datetime.datetime,
        acknowledged_until: datetime.datetime | None = None,
        snoozed_until: datetime.datetime | None = None,
        parent: Parent | None = None,
    ): ...
    @property
    def acknowledged(self) -> datetime.datetime | None: ...
    @property
    def alarm(self) -> Alarm: ...
    @property
    def parent(self) -> Parent | None: ...
    def is_active(self) -> bool: ...
    @property
    def trigger(self) -> datetime.date: ...

class Alarms:
    def __init__(self, component: Alarm | Event | Todo | None = None): ...
    def add_component(self, component: Alarm | Parent) -> None: ...
    def set_parent(self, parent: Parent) -> None: ...
    def add_alarm(self, alarm: Alarm) -> None: ...
    def set_start(self, dt: datetime.date | None) -> None: ...
    def set_end(self, dt: datetime.date | None) -> None: ...
    def acknowledge_until(self, dt: datetime.date | None) -> None: ...
    def snooze_until(self, dt: datetime.date | None) -> None: ...
    def set_local_timezone(self, tzinfo: datetime.tzinfo | str | None) -> None: ...
    @property
    def times(self) -> list[AlarmTime]: ...
    @property
    def active(self) -> list[AlarmTime]: ...



from _typeshed import Incomplete
from collections.abc import Generator

from corus.record import Record

__all__ = ["load_mokoron"]

class MokoronRecord(Record):
    __attributes__: Incomplete
    id: Incomplete
    timestamp: Incomplete
    user: Incomplete
    text: Incomplete
    sentiment: Incomplete
    replies: Incomplete
    retweets: Incomplete
    favourites: Incomplete
    posts: Incomplete
    followers: Incomplete
    friends: Incomplete
    lists: Incomplete
    def __init__(
        self, id, timestamp, user, text, sentiment, replies, retweets, favourites, posts, followers, friends, lists
    ) -> None: ...
    @classmethod
    def from_match(cls, match): ...

def load_mokoron(path) -> Generator[Incomplete]: ...



from _typeshed import Incomplete

from corus.record import Record

__all__ = [
    "load_ods_interfax",
    "load_ods_gazeta",
    "load_ods_izvestia",
    "load_ods_meduza",
    "load_ods_ria",
    "load_ods_rt",
    "load_ods_tass",
]

class NewsRecord(Record):
    __attributes__: Incomplete
    timestamp: Incomplete
    url: Incomplete
    edition: Incomplete
    topics: Incomplete
    authors: Incomplete
    title: Incomplete
    text: Incomplete
    stats: Incomplete
    def __init__(self, timestamp, url, edition, topics, authors, title, text, stats) -> None: ...

class Stats(Record):
    __attributes__: Incomplete
    fb: Incomplete
    vk: Incomplete
    ok: Incomplete
    twitter: Incomplete
    lj: Incomplete
    tg: Incomplete
    likes: Incomplete
    views: Incomplete
    comments: Incomplete
    def __init__(self, fb, vk, ok, twitter, lj, tg, likes, views, comments) -> None: ...

def load_ods_interfax(path): ...
def load_ods_gazeta(path): ...
def load_ods_izvestia(path): ...
def load_ods_meduza(path): ...
def load_ods_ria(path): ...
def load_ods_rt(path): ...
def load_ods_tass(path): ...



from _typeshed import Incomplete

PORT_SPEC: Incomplete

def add_port_mapping(port_bindings, internal_port, external) -> None: ...
def add_port(port_bindings, internal_port_range, external_range) -> None: ...
def build_port_bindings(ports): ...
def port_range(start, end, proto, randomly_available_port: bool = False): ...
def split_port(port): ...



from _typeshed import SupportsKeysAndGetItem

from networkx.classes.graph import Graph, _Edge, _Node
from networkx.utils.backends import _dispatchable

@_dispatchable
def closeness_centrality(
    G: Graph[_Node], u: _Node | None = None, distance: str | None = None, wf_improved: bool = True
) -> dict[_Node, float]: ...
@_dispatchable
def incremental_closeness_centrality(
    G: Graph[_Node],
    edge: _Edge[_Node],
    prev_cc: SupportsKeysAndGetItem[_Node, float] | None = None,
    insertion: bool = True,
    wf_improved: bool = True,
) -> dict[_Node, float]: ...



from _typeshed import Incomplete

class TaskTemplate(dict[str, Incomplete]):
    def __init__(
        self,
        container_spec,
        resources: Incomplete | None = None,
        restart_policy: Incomplete | None = None,
        placement: Incomplete | None = None,
        log_driver: Incomplete | None = None,
        networks: Incomplete | None = None,
        force_update: Incomplete | None = None,
    ) -> None: ...
    @property
    def container_spec(self): ...
    @property
    def resources(self): ...
    @property
    def restart_policy(self): ...
    @property
    def placement(self): ...

class ContainerSpec(dict[str, Incomplete]):
    def __init__(
        self,
        image,
        command: Incomplete | None = None,
        args: Incomplete | None = None,
        hostname: Incomplete | None = None,
        env: Incomplete | None = None,
        workdir: Incomplete | None = None,
        user: Incomplete | None = None,
        labels: Incomplete | None = None,
        mounts: Incomplete | None = None,
        stop_grace_period: Incomplete | None = None,
        secrets: Incomplete | None = None,
        tty: Incomplete | None = None,
        groups: Incomplete | None = None,
        open_stdin: Incomplete | None = None,
        read_only: Incomplete | None = None,
        stop_signal: Incomplete | None = None,
        healthcheck: Incomplete | None = None,
        hosts: Incomplete | None = None,
        dns_config: Incomplete | None = None,
        configs: Incomplete | None = None,
        privileges: Incomplete | None = None,
        isolation: Incomplete | None = None,
        init: Incomplete | None = None,
        cap_add: Incomplete | None = None,
        cap_drop: Incomplete | None = None,
        sysctls: Incomplete | None = None,
    ) -> None: ...

class Mount(dict[str, Incomplete]):
    def __init__(
        self,
        target,
        source,
        type: str = "volume",
        read_only: bool = False,
        consistency: Incomplete | None = None,
        propagation: Incomplete | None = None,
        no_copy: bool = False,
        labels: Incomplete | None = None,
        driver_config: Incomplete | None = None,
        tmpfs_size: Incomplete | None = None,
        tmpfs_mode: Incomplete | None = None,
    ) -> None: ...
    @classmethod
    def parse_mount_string(cls, string): ...

class Resources(dict[str, Incomplete]):
    def __init__(
        self,
        cpu_limit: Incomplete | None = None,
        mem_limit: Incomplete | None = None,
        cpu_reservation: Incomplete | None = None,
        mem_reservation: Incomplete | None = None,
        generic_resources: Incomplete | None = None,
    ) -> None: ...

class UpdateConfig(dict[str, Incomplete]):
    def __init__(
        self,
        parallelism: int = 0,
        delay: Incomplete | None = None,
        failure_action: str = "continue",
        monitor: Incomplete | None = None,
        max_failure_ratio: Incomplete | None = None,
        order: Incomplete | None = None,
    ) -> None: ...

class RollbackConfig(UpdateConfig): ...

class RestartConditionTypesEnum:
    NONE: Incomplete
    ON_FAILURE: Incomplete
    ANY: Incomplete

class RestartPolicy(dict[str, Incomplete]):
    condition_types: type[RestartConditionTypesEnum]
    def __init__(self, condition="none", delay: int = 0, max_attempts: int = 0, window: int = 0) -> None: ...

class DriverConfig(dict[str, Incomplete]):
    def __init__(self, name, options: Incomplete | None = None) -> None: ...

class EndpointSpec(dict[str, Incomplete]):
    def __init__(self, mode: Incomplete | None = None, ports: Incomplete | None = None) -> None: ...

def convert_service_ports(ports): ...

class ServiceMode(dict[str, Incomplete]):
    mode: Incomplete
    def __init__(self, mode, replicas: Incomplete | None = None, concurrency: Incomplete | None = None) -> None: ...
    @property
    def replicas(self): ...

class SecretReference(dict[str, Incomplete]):
    def __init__(
        self,
        secret_id,
        secret_name,
        filename: Incomplete | None = None,
        uid: Incomplete | None = None,
        gid: Incomplete | None = None,
        mode: int = 292,
    ) -> None: ...

class ConfigReference(dict[str, Incomplete]):
    def __init__(
        self,
        config_id,
        config_name,
        filename: Incomplete | None = None,
        uid: Incomplete | None = None,
        gid: Incomplete | None = None,
        mode: int = 292,
    ) -> None: ...

class Placement(dict[str, Incomplete]):
    def __init__(
        self,
        constraints: Incomplete | None = None,
        preferences: Incomplete | None = None,
        platforms: Incomplete | None = None,
        maxreplicas: Incomplete | None = None,
    ) -> None: ...

class PlacementPreference(dict[str, Incomplete]):
    def __init__(self, strategy, descriptor) -> None: ...

class DNSConfig(dict[str, Incomplete]):
    def __init__(
        self, nameservers: Incomplete | None = None, search: Incomplete | None = None, options: Incomplete | None = None
    ) -> None: ...

class Privileges(dict[str, Incomplete]):
    def __init__(
        self,
        credentialspec_file: Incomplete | None = None,
        credentialspec_registry: Incomplete | None = None,
        selinux_disable: Incomplete | None = None,
        selinux_user: Incomplete | None = None,
        selinux_role: Incomplete | None = None,
        selinux_type: Incomplete | None = None,
        selinux_level: Incomplete | None = None,
    ) -> None: ...

class NetworkAttachmentConfig(dict[str, Incomplete]):
    def __init__(self, target, aliases: Incomplete | None = None, options: Incomplete | None = None) -> None: ...



from _typeshed import Incomplete

from authlib.oauth2.rfc6749 import BaseGrant, TokenEndpointMixin

JWT_BEARER_GRANT_TYPE: str

class JWTBearerGrant(BaseGrant, TokenEndpointMixin):
    GRANT_TYPE = JWT_BEARER_GRANT_TYPE
    CLAIMS_OPTIONS: Incomplete
    @staticmethod
    def sign(
        key,
        issuer,
        audience,
        subject: Incomplete | None = None,
        issued_at: Incomplete | None = None,
        expires_at: Incomplete | None = None,
        claims: Incomplete | None = None,
        **kwargs,
    ): ...
    def process_assertion_claims(self, assertion): ...
    def resolve_public_key(self, headers, payload): ...
    def validate_token_request(self) -> None: ...
    def create_token_response(self): ...
    def resolve_issuer_client(self, issuer) -> None: ...
    def resolve_client_key(self, client, headers, payload) -> None: ...
    def authenticate_user(self, subject) -> None: ...
    def has_granted_permission(self, client, user) -> None: ...



from _typeshed import Incomplete

class AuthlibBaseError(Exception):
    error: Incomplete
    description: str
    uri: Incomplete
    def __init__(
        self, error: Incomplete | None = None, description: Incomplete | None = None, uri: Incomplete | None = None
    ) -> None: ...

class AuthlibHTTPError(AuthlibBaseError):
    status_code: int
    def __init__(
        self,
        error: Incomplete | None = None,
        description: Incomplete | None = None,
        uri: Incomplete | None = None,
        status_code: Incomplete | None = None,
    ) -> None: ...
    def get_error_description(self): ...
    def get_body(self): ...
    def get_headers(self): ...
    uri: Incomplete
    def __call__(self, uri: Incomplete | None = None): ...

class ContinueIteration(AuthlibBaseError): ...



from _typeshed import Incomplete

class JWTBearerTokenGenerator:
    DEFAULT_EXPIRES_IN: int
    secret_key: Incomplete
    issuer: Incomplete
    alg: Incomplete
    def __init__(self, secret_key, issuer: Incomplete | None = None, alg: str = "RS256") -> None: ...
    @staticmethod
    def get_allowed_scope(client, scope): ...
    @staticmethod
    def get_sub_value(user): ...
    def get_token_data(self, grant_type, client, expires_in, user: Incomplete | None = None, scope: Incomplete | None = None): ...
    def generate(
        self,
        grant_type,
        client,
        user: Incomplete | None = None,
        scope: Incomplete | None = None,
        expires_in: Incomplete | None = None,
    ): ...
    def __call__(
        self,
        grant_type,
        client,
        user: Incomplete | None = None,
        scope: Incomplete | None = None,
        expires_in: Incomplete | None = None,
        include_refresh_token: bool = True,
    ): ...



from _typeshed import Incomplete

class ConfigApiMixin:
    def create_config(self, name, data, labels: Incomplete | None = None, templating: Incomplete | None = None): ...
    def inspect_config(self, id): ...
    def remove_config(self, id): ...
    def configs(self, filters: Incomplete | None = None): ...



def fp_str(*a): ...
def unicode2T1(utext, fonts): ...
def instanceStringWidthT1(self, text, size, encoding: str = "utf8"): ...
def instanceStringWidthTTF(self, text, size, encoding: str = "utf8"): ...
def hex32(i): ...
def add32(x, y): ...
def calcChecksum(data): ...
def escapePDF(s): ...
def asciiBase85Encode(input): ...
def asciiBase85Decode(input): ...
def sameFrag(f, g): ...



def nullTransform(): ...
def translate(dx: float, dy: float = 0): ...
def scale(sx: float, sy: float = 1): ...
def rotate(angle: float, cx: float = 0, cy: float = 0): ...
def skewX(angle: float): ...
def skewY(angle: float): ...
def mmult(A, B): ...
def inverse(A): ...
def zTransformPoint(A, v): ...
def transformPoint(A, v): ...
def transformPoints(matrix, V): ...
def zTransformPoints(matrix, V): ...



from _typeshed import Incomplete

__all__ = ["load_taiga_fontanka_metas", "load_taiga_fontanka"]

def load_taiga_fontanka_metas(path, offset: int = 0, count=13): ...
def load_taiga_fontanka(path, metas: Incomplete | None = None, offset: int = 306359296, count: int = 342683): ...



from _typeshed import Incomplete

this_dir: Incomplete

class FilterParameters:
    Name: Incomplete
    Description: Incomplete
    Path: Incomplete
    Server: Incomplete
    AddExtensionFile: bool
    AddExtensionFile_Enabled: bool
    AddExtensionFile_GroupID: Incomplete
    AddExtensionFile_CanDelete: bool
    AddExtensionFile_Description: Incomplete
    def __init__(self, **kw) -> None: ...

class VirtualDirParameters:
    Name: Incomplete
    Description: Incomplete
    AppProtection: Incomplete
    Headers: Incomplete
    Path: Incomplete
    Type: Incomplete
    AccessExecute: Incomplete
    AccessRead: Incomplete
    AccessWrite: Incomplete
    AccessScript: Incomplete
    ContentIndexed: Incomplete
    EnableDirBrowsing: Incomplete
    EnableDefaultDoc: Incomplete
    DefaultDoc: Incomplete
    ScriptMaps: list[ScriptMapParams]
    ScriptMapUpdate: str
    Server: Incomplete
    def __init__(self, **kw) -> None: ...
    def is_root(self): ...
    def split_path(self): ...

class ScriptMapParams:
    Extension: Incomplete
    Module: Incomplete
    Flags: int
    Verbs: str
    AddExtensionFile: bool
    AddExtensionFile_Enabled: bool
    AddExtensionFile_GroupID: Incomplete
    AddExtensionFile_CanDelete: bool
    AddExtensionFile_Description: Incomplete
    def __init__(self, **kw) -> None: ...

class ISAPIParameters:
    ServerName: Incomplete
    Filters: list[FilterParameters]
    VirtualDirs: list[VirtualDirParameters]
    def __init__(self, **kw) -> None: ...

verbose: int

def log(level, what) -> None: ...

class InstallationError(Exception): ...
class ItemNotFound(InstallationError): ...
class ConfigurationError(InstallationError): ...

def FindPath(options, server, name): ...
def LocateWebServerPath(description): ...
def GetWebServer(description: Incomplete | None = None): ...
def LoadWebServer(path): ...
def FindWebServer(options, server_desc): ...
def split_path(path): ...
def CreateDirectory(params, options): ...
def AssignScriptMaps(script_maps, target, update: str = "replace") -> None: ...
def get_unique_items(sequence, reference): ...
def CreateISAPIFilter(filterParams, options): ...
def DeleteISAPIFilter(filterParams, options) -> None: ...
def AddExtensionFiles(params, options) -> None: ...
def DeleteExtensionFileRecords(params, options) -> None: ...
def CheckLoaderModule(dll_name) -> None: ...
def Install(params, options) -> None: ...
def RemoveDirectory(params, options) -> None: ...
def RemoveScriptMaps(vd_params, options) -> None: ...
def Uninstall(params, options) -> None: ...
def GetLoaderModuleName(mod_name, check_module: Incomplete | None = None): ...
def InstallModule(conf_module_name, params, options, log=...) -> None: ...
def UninstallModule(conf_module_name, params, options, log=...) -> None: ...

standard_arguments: Incomplete

def build_usage(handler_map): ...
def MergeStandardOptions(options, params) -> None: ...
def HandleCommandLine(
    params,
    argv: Incomplete | None = None,
    conf_module_name: Incomplete | None = None,
    default_arg: str = "install",
    opt_parser: Incomplete | None = None,
    custom_arg_handlers={},
) -> None: ...



from _typeshed import Incomplete

from networkx.utils.backends import _dispatchable

@_dispatchable
def reciprocity(G, nodes: Incomplete | None = None): ...
@_dispatchable
def overall_reciprocity(G): ...



from collections.abc import Awaitable, Callable, Generator
from contextlib import AbstractAsyncContextManager
from types import TracebackType
from typing import Any, BinaryIO, Generic, TextIO, TypeVar
from typing_extensions import Self

_T = TypeVar("_T")
_V_co = TypeVar("_V_co", covariant=True)

class AsyncBase(Generic[_T]):
    def __init__(self, file: str, loop: Any, executor: Any) -> None: ...
    def __aiter__(self) -> Self: ...
    async def __anext__(self) -> _T: ...

class AsyncIndirectBase(AsyncBase[_T]):
    def __init__(self, name: str, loop: Any, executor: Any, indirect: Callable[[], TextIO | BinaryIO]) -> None: ...

class AiofilesContextManager(Awaitable[_V_co], AbstractAsyncContextManager[_V_co]):
    def __init__(self, coro: Awaitable[_V_co]) -> None: ...
    def __await__(self) -> Generator[Any, Any, _V_co]: ...
    async def __aenter__(self) -> _V_co: ...
    async def __aexit__(
        self, exc_type: type[BaseException] | None, exc_val: BaseException | None, exc_tb: TracebackType | None
    ) -> None: ...



from typing import Any

import click

class FieldId:
    SEPARATOR: str

    def __init__(
        self,
        command_index: int,
        param_index: int,
        param_type: str,
        click_type: str,
        nargs: int,
        form_type: str,
        name: str,
        key: str | None = None,
    ): ...
    @classmethod
    def from_string(cls, field_info_as_string: str) -> FieldId: ...

class NotSupported(ValueError): ...

class BaseInput:
    param_type_cls: type | None
    def __init__(self, ctx: click.Context, param: click.Parameter, command_index: int, param_index: int) -> None: ...
    def is_supported(self) -> bool: ...
    @property
    def fields(self) -> dict[str, Any]: ...
    @property
    def type_attrs(self) -> dict[str, Any]: ...
    def _to_cmd_line_name(self, name: str) -> str: ...
    def _build_name(self, name: str): ...

class ChoiceInput(BaseInput): ...
class FlagInput(BaseInput): ...
class IntInput(BaseInput): ...
class FloatInput(BaseInput): ...
class FolderInput(BaseInput): ...
class FileInput(BaseInput): ...
class EmailInput(BaseInput): ...
class PasswordInput(BaseInput): ...
class TextAreaInput(BaseInput): ...
class DefaultInput(BaseInput): ...

INPUT_TYPES: list[type]
_DEFAULT_INPUT: list[type]

def get_input_field(ctx: click.Context, param: click.Parameter, command_index, param_index) -> dict[str, Any]: ...
